# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.apps._secret_create_params import (
    SecretCreateParams as SecretCreateParams,
)
from stripe.params.apps._secret_delete_where_params import (
    SecretDeleteWhereParams as SecretDeleteWhereParams,
)
from stripe.params.apps._secret_find_params import (
    SecretFindParams as SecretFindParams,
)
from stripe.params.apps._secret_list_params import (
    SecretListParams as SecretListParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.core._event_destination_create_params import (
    EventDestinationCreateParams as EventDestinationCreateParams,
)
from stripe.params.v2.core._event_destination_delete_params import (
    EventDestinationDeleteParams as EventDestinationDeleteParams,
)
from stripe.params.v2.core._event_destination_disable_params import (
    EventDestinationDisableParams as EventDestinationDisableParams,
)
from stripe.params.v2.core._event_destination_enable_params import (
    EventDestinationEnableParams as EventDestinationEnableParams,
)
from stripe.params.v2.core._event_destination_list_params import (
    EventDestinationListParams as EventDestinationListParams,
)
from stripe.params.v2.core._event_destination_ping_params import (
    EventDestinationPingParams as EventDestinationPingParams,
)
from stripe.params.v2.core._event_destination_retrieve_params import (
    EventDestinationRetrieveParams as EventDestinationRetrieveParams,
)
from stripe.params.v2.core._event_destination_update_params import (
    EventDestinationUpdateParams as EventDestinationUpdateParams,
)
from stripe.params.v2.core._event_list_params import (
    EventListParams as EventListParams,
)
from stripe.params.v2.core._event_retrieve_params import (
    EventRetrieveParams as EventRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.radar._early_fraud_warning_list_params import (
    EarlyFraudWarningListParams as EarlyFraudWarningListParams,
)
from stripe.params.radar._early_fraud_warning_retrieve_params import (
    EarlyFraudWarningRetrieveParams as EarlyFraudWarningRetrieveParams,
)
from stripe.params.radar._value_list_create_params import (
    ValueListCreateParams as ValueListCreateParams,
)
from stripe.params.radar._value_list_delete_params import (
    ValueListDeleteParams as ValueListDeleteParams,
)
from stripe.params.radar._value_list_item_create_params import (
    ValueListItemCreateParams as ValueListItemCreateParams,
)
from stripe.params.radar._value_list_item_delete_params import (
    ValueListItemDeleteParams as ValueListItemDeleteParams,
)
from stripe.params.radar._value_list_item_list_params import (
    ValueListItemListParams as ValueListItemListParams,
)
from stripe.params.radar._value_list_item_retrieve_params import (
    ValueListItemRetrieveParams as ValueListItemRetrieveParams,
)
from stripe.params.radar._value_list_list_params import (
    ValueListListParams as ValueListListParams,
)
from stripe.params.radar._value_list_modify_params import (
    ValueListModifyParams as ValueListModifyParams,
)
from stripe.params.radar._value_list_retrieve_params import (
    ValueListRetrieveParams as ValueListRetrieveParams,
)
from stripe.params.radar._value_list_update_params import (
    ValueListUpdateParams as ValueListUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.issuing._transaction import Transaction
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.issuing._transaction_list_params import (
        TransactionListParams,
    )
    from stripe.params.issuing._transaction_retrieve_params import (
        TransactionRetrieveParams,
    )
    from stripe.params.issuing._transaction_update_params import (
        TransactionUpdateParams,
    )


class TransactionService(StripeService):
    def list(
        self,
        params: Optional["TransactionListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Transaction]:
        """
        Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        return cast(
            ListObject[Transaction],
            self._request(
                "get",
                "/v1/issuing/transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["TransactionListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Transaction]:
        """
        Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        return cast(
            ListObject[Transaction],
            await self._request_async(
                "get",
                "/v1/issuing/transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        transaction: str,
        params: Optional["TransactionRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Transaction:
        """
        Retrieves an Issuing Transaction object.
        """
        return cast(
            Transaction,
            self._request(
                "get",
                "/v1/issuing/transactions/{transaction}".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        transaction: str,
        params: Optional["TransactionRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Transaction:
        """
        Retrieves an Issuing Transaction object.
        """
        return cast(
            Transaction,
            await self._request_async(
                "get",
                "/v1/issuing/transactions/{transaction}".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        transaction: str,
        params: Optional["TransactionUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Transaction:
        """
        Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            Transaction,
            self._request(
                "post",
                "/v1/issuing/transactions/{transaction}".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        transaction: str,
        params: Optional["TransactionUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Transaction:
        """
        Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            Transaction,
            await self._request_async(
                "post",
                "/v1/issuing/transactions/{transaction}".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.billing._meter_event_adjustment_create_params import (
    MeterEventAdjustmentCreateParams as MeterEventAdjustmentCreateParams,
)
from stripe.params.v2.billing._meter_event_create_params import (
    MeterEventCreateParams as MeterEventCreateParams,
)
from stripe.params.v2.billing._meter_event_session_create_params import (
    MeterEventSessionCreateParams as MeterEventSessionCreateParams,
)
from stripe.params.v2.billing._meter_event_stream_create_params import (
    MeterEventStreamCreateParams as MeterEventStreamCreateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.financial_connections._account_disconnect_params import (
    AccountDisconnectParams as AccountDisconnectParams,
)
from stripe.params.financial_connections._account_list_owners_params import (
    AccountListOwnersParams as AccountListOwnersParams,
)
from stripe.params.financial_connections._account_list_params import (
    AccountListParams as AccountListParams,
)
from stripe.params.financial_connections._account_owner_list_params import (
    AccountOwnerListParams as AccountOwnerListParams,
)
from stripe.params.financial_connections._account_refresh_account_params import (
    AccountRefreshAccountParams as AccountRefreshAccountParams,
)
from stripe.params.financial_connections._account_refresh_params import (
    AccountRefreshParams as AccountRefreshParams,
)
from stripe.params.financial_connections._account_retrieve_params import (
    AccountRetrieveParams as AccountRetrieveParams,
)
from stripe.params.financial_connections._account_subscribe_params import (
    AccountSubscribeParams as AccountSubscribeParams,
)
from stripe.params.financial_connections._account_unsubscribe_params import (
    AccountUnsubscribeParams as AccountUnsubscribeParams,
)
from stripe.params.financial_connections._session_create_params import (
    SessionCreateParams as SessionCreateParams,
)
from stripe.params.financial_connections._session_retrieve_params import (
    SessionRetrieveParams as SessionRetrieveParams,
)
from stripe.params.financial_connections._transaction_list_params import (
    TransactionListParams as TransactionListParams,
)
from stripe.params.financial_connections._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers.issuing._authorization_capture_params import (
    AuthorizationCaptureParams as AuthorizationCaptureParams,
)
from stripe.params.test_helpers.issuing._authorization_create_params import (
    AuthorizationCreateParams as AuthorizationCreateParams,
)
from stripe.params.test_helpers.issuing._authorization_expire_params import (
    AuthorizationExpireParams as AuthorizationExpireParams,
)
from stripe.params.test_helpers.issuing._authorization_finalize_amount_params import (
    AuthorizationFinalizeAmountParams as AuthorizationFinalizeAmountParams,
)
from stripe.params.test_helpers.issuing._authorization_increment_params import (
    AuthorizationIncrementParams as AuthorizationIncrementParams,
)
from stripe.params.test_helpers.issuing._authorization_respond_params import (
    AuthorizationRespondParams as AuthorizationRespondParams,
)
from stripe.params.test_helpers.issuing._authorization_reverse_params import (
    AuthorizationReverseParams as AuthorizationReverseParams,
)
from stripe.params.test_helpers.issuing._card_deliver_card_params import (
    CardDeliverCardParams as CardDeliverCardParams,
)
from stripe.params.test_helpers.issuing._card_fail_card_params import (
    CardFailCardParams as CardFailCardParams,
)
from stripe.params.test_helpers.issuing._card_return_card_params import (
    CardReturnCardParams as CardReturnCardParams,
)
from stripe.params.test_helpers.issuing._card_ship_card_params import (
    CardShipCardParams as CardShipCardParams,
)
from stripe.params.test_helpers.issuing._card_submit_card_params import (
    CardSubmitCardParams as CardSubmitCardParams,
)
from stripe.params.test_helpers.issuing._personalization_design_activate_params import (
    PersonalizationDesignActivateParams as PersonalizationDesignActivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_deactivate_params import (
    PersonalizationDesignDeactivateParams as PersonalizationDesignDeactivateParams,
)
from stripe.params.test_helpers.issuing._personalization_design_reject_params import (
    PersonalizationDesignRejectParams as PersonalizationDesignRejectParams,
)
from stripe.params.test_helpers.issuing._transaction_create_force_capture_params import (
    TransactionCreateForceCaptureParams as TransactionCreateForceCaptureParams,
)
from stripe.params.test_helpers.issuing._transaction_create_unlinked_refund_params import (
    TransactionCreateUnlinkedRefundParams as TransactionCreateUnlinkedRefundParams,
)
from stripe.params.test_helpers.issuing._transaction_refund_params import (
    TransactionRefundParams as TransactionRefundParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.forwarding._request_create_params import (
    RequestCreateParams as RequestCreateParams,
)
from stripe.params.forwarding._request_list_params import (
    RequestListParams as RequestListParams,
)
from stripe.params.forwarding._request_retrieve_params import (
    RequestRetrieveParams as RequestRetrieveParams,
)



# -*- coding: utf-8 -*-

from stripe.v2.core._event import (
    UnknownEventNotification as UnknownEventNotification,
)

# The beginning of the section generated from our OpenAPI spec
from stripe.events._event_classes import (
    ALL_EVENT_NOTIFICATIONS as ALL_EVENT_NOTIFICATIONS,
)
from stripe.events._v1_billing_meter_error_report_triggered_event import (
    V1BillingMeterErrorReportTriggeredEvent as V1BillingMeterErrorReportTriggeredEvent,
    V1BillingMeterErrorReportTriggeredEventNotification as V1BillingMeterErrorReportTriggeredEventNotification,
)
from stripe.events._v1_billing_meter_no_meter_found_event import (
    V1BillingMeterNoMeterFoundEvent as V1BillingMeterNoMeterFoundEvent,
    V1BillingMeterNoMeterFoundEventNotification as V1BillingMeterNoMeterFoundEventNotification,
)
from stripe.events._v2_core_event_destination_ping_event import (
    V2CoreEventDestinationPingEvent as V2CoreEventDestinationPingEvent,
    V2CoreEventDestinationPingEventNotification as V2CoreEventDestinationPingEventNotification,
)
# The end of the section generated from our OpenAPI spec



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.terminal._configuration import Configuration
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.terminal._configuration_create_params import (
        ConfigurationCreateParams,
    )
    from stripe.params.terminal._configuration_delete_params import (
        ConfigurationDeleteParams,
    )
    from stripe.params.terminal._configuration_list_params import (
        ConfigurationListParams,
    )
    from stripe.params.terminal._configuration_retrieve_params import (
        ConfigurationRetrieveParams,
    )
    from stripe.params.terminal._configuration_update_params import (
        ConfigurationUpdateParams,
    )


class ConfigurationService(StripeService):
    def delete(
        self,
        configuration: str,
        params: Optional["ConfigurationDeleteParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Deletes a Configuration object.
        """
        return cast(
            Configuration,
            self._request(
                "delete",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def delete_async(
        self,
        configuration: str,
        params: Optional["ConfigurationDeleteParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Deletes a Configuration object.
        """
        return cast(
            Configuration,
            await self._request_async(
                "delete",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        configuration: str,
        params: Optional["ConfigurationRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Retrieves a Configuration object.
        """
        return cast(
            Configuration,
            self._request(
                "get",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        configuration: str,
        params: Optional["ConfigurationRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Retrieves a Configuration object.
        """
        return cast(
            Configuration,
            await self._request_async(
                "get",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        configuration: str,
        params: Optional["ConfigurationUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Updates a new Configuration object.
        """
        return cast(
            Configuration,
            self._request(
                "post",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        configuration: str,
        params: Optional["ConfigurationUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Updates a new Configuration object.
        """
        return cast(
            Configuration,
            await self._request_async(
                "post",
                "/v1/terminal/configurations/{configuration}".format(
                    configuration=sanitize_id(configuration),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def list(
        self,
        params: Optional["ConfigurationListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Configuration]:
        """
        Returns a list of Configuration objects.
        """
        return cast(
            ListObject[Configuration],
            self._request(
                "get",
                "/v1/terminal/configurations",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["ConfigurationListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Configuration]:
        """
        Returns a list of Configuration objects.
        """
        return cast(
            ListObject[Configuration],
            await self._request_async(
                "get",
                "/v1/terminal/configurations",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: Optional["ConfigurationCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Creates a new Configuration object.
        """
        return cast(
            Configuration,
            self._request(
                "post",
                "/v1/terminal/configurations",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: Optional["ConfigurationCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Configuration:
        """
        Creates a new Configuration object.
        """
        return cast(
            Configuration,
            await self._request_async(
                "post",
                "/v1/terminal/configurations",
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.reporting._report_run_create_params import (
    ReportRunCreateParams as ReportRunCreateParams,
)
from stripe.params.reporting._report_run_list_params import (
    ReportRunListParams as ReportRunListParams,
)
from stripe.params.reporting._report_run_retrieve_params import (
    ReportRunRetrieveParams as ReportRunRetrieveParams,
)
from stripe.params.reporting._report_type_list_params import (
    ReportTypeListParams as ReportTypeListParams,
)
from stripe.params.reporting._report_type_retrieve_params import (
    ReportTypeRetrieveParams as ReportTypeRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.identity._verification_report_list_params import (
    VerificationReportListParams as VerificationReportListParams,
)
from stripe.params.identity._verification_report_retrieve_params import (
    VerificationReportRetrieveParams as VerificationReportRetrieveParams,
)
from stripe.params.identity._verification_session_cancel_params import (
    VerificationSessionCancelParams as VerificationSessionCancelParams,
)
from stripe.params.identity._verification_session_create_params import (
    VerificationSessionCreateParams as VerificationSessionCreateParams,
)
from stripe.params.identity._verification_session_list_params import (
    VerificationSessionListParams as VerificationSessionListParams,
)
from stripe.params.identity._verification_session_modify_params import (
    VerificationSessionModifyParams as VerificationSessionModifyParams,
)
from stripe.params.identity._verification_session_redact_params import (
    VerificationSessionRedactParams as VerificationSessionRedactParams,
)
from stripe.params.identity._verification_session_retrieve_params import (
    VerificationSessionRetrieveParams as VerificationSessionRetrieveParams,
)
from stripe.params.identity._verification_session_update_params import (
    VerificationSessionUpdateParams as VerificationSessionUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params import (
    apps as apps,
    billing as billing,
    billing_portal as billing_portal,
    checkout as checkout,
    climate as climate,
    entitlements as entitlements,
    financial_connections as financial_connections,
    forwarding as forwarding,
    identity as identity,
    issuing as issuing,
    radar as radar,
    reporting as reporting,
    sigma as sigma,
    tax as tax,
    terminal as terminal,
    test_helpers as test_helpers,
    treasury as treasury,
)
from stripe.params._account_capability_list_params import (
    AccountCapabilityListParams as AccountCapabilityListParams,
)
from stripe.params._account_capability_retrieve_params import (
    AccountCapabilityRetrieveParams as AccountCapabilityRetrieveParams,
)
from stripe.params._account_capability_update_params import (
    AccountCapabilityUpdateParams as AccountCapabilityUpdateParams,
)
from stripe.params._account_create_external_account_params import (
    AccountCreateExternalAccountParams as AccountCreateExternalAccountParams,
)
from stripe.params._account_create_login_link_params import (
    AccountCreateLoginLinkParams as AccountCreateLoginLinkParams,
)
from stripe.params._account_create_params import (
    AccountCreateParams as AccountCreateParams,
)
from stripe.params._account_create_person_params import (
    AccountCreatePersonParams as AccountCreatePersonParams,
)
from stripe.params._account_delete_external_account_params import (
    AccountDeleteExternalAccountParams as AccountDeleteExternalAccountParams,
)
from stripe.params._account_delete_params import (
    AccountDeleteParams as AccountDeleteParams,
)
from stripe.params._account_delete_person_params import (
    AccountDeletePersonParams as AccountDeletePersonParams,
)
from stripe.params._account_external_account_create_params import (
    AccountExternalAccountCreateParams as AccountExternalAccountCreateParams,
)
from stripe.params._account_external_account_delete_params import (
    AccountExternalAccountDeleteParams as AccountExternalAccountDeleteParams,
)
from stripe.params._account_external_account_list_params import (
    AccountExternalAccountListParams as AccountExternalAccountListParams,
)
from stripe.params._account_external_account_retrieve_params import (
    AccountExternalAccountRetrieveParams as AccountExternalAccountRetrieveParams,
)
from stripe.params._account_external_account_update_params import (
    AccountExternalAccountUpdateParams as AccountExternalAccountUpdateParams,
)
from stripe.params._account_link_create_params import (
    AccountLinkCreateParams as AccountLinkCreateParams,
)
from stripe.params._account_list_capabilities_params import (
    AccountListCapabilitiesParams as AccountListCapabilitiesParams,
)
from stripe.params._account_list_external_accounts_params import (
    AccountListExternalAccountsParams as AccountListExternalAccountsParams,
)
from stripe.params._account_list_params import (
    AccountListParams as AccountListParams,
)
from stripe.params._account_list_persons_params import (
    AccountListPersonsParams as AccountListPersonsParams,
)
from stripe.params._account_login_link_create_params import (
    AccountLoginLinkCreateParams as AccountLoginLinkCreateParams,
)
from stripe.params._account_modify_capability_params import (
    AccountModifyCapabilityParams as AccountModifyCapabilityParams,
)
from stripe.params._account_modify_external_account_params import (
    AccountModifyExternalAccountParams as AccountModifyExternalAccountParams,
)
from stripe.params._account_modify_person_params import (
    AccountModifyPersonParams as AccountModifyPersonParams,
)
from stripe.params._account_person_create_params import (
    AccountPersonCreateParams as AccountPersonCreateParams,
)
from stripe.params._account_person_delete_params import (
    AccountPersonDeleteParams as AccountPersonDeleteParams,
)
from stripe.params._account_person_list_params import (
    AccountPersonListParams as AccountPersonListParams,
)
from stripe.params._account_person_retrieve_params import (
    AccountPersonRetrieveParams as AccountPersonRetrieveParams,
)
from stripe.params._account_person_update_params import (
    AccountPersonUpdateParams as AccountPersonUpdateParams,
)
from stripe.params._account_persons_params import (
    AccountPersonsParams as AccountPersonsParams,
)
from stripe.params._account_reject_params import (
    AccountRejectParams as AccountRejectParams,
)
from stripe.params._account_retrieve_capability_params import (
    AccountRetrieveCapabilityParams as AccountRetrieveCapabilityParams,
)
from stripe.params._account_retrieve_current_params import (
    AccountRetrieveCurrentParams as AccountRetrieveCurrentParams,
)
from stripe.params._account_retrieve_external_account_params import (
    AccountRetrieveExternalAccountParams as AccountRetrieveExternalAccountParams,
)
from stripe.params._account_retrieve_params import (
    AccountRetrieveParams as AccountRetrieveParams,
)
from stripe.params._account_retrieve_person_params import (
    AccountRetrievePersonParams as AccountRetrievePersonParams,
)
from stripe.params._account_session_create_params import (
    AccountSessionCreateParams as AccountSessionCreateParams,
)
from stripe.params._account_update_params import (
    AccountUpdateParams as AccountUpdateParams,
)
from stripe.params._apple_pay_domain_create_params import (
    ApplePayDomainCreateParams as ApplePayDomainCreateParams,
)
from stripe.params._apple_pay_domain_delete_params import (
    ApplePayDomainDeleteParams as ApplePayDomainDeleteParams,
)
from stripe.params._apple_pay_domain_list_params import (
    ApplePayDomainListParams as ApplePayDomainListParams,
)
from stripe.params._apple_pay_domain_retrieve_params import (
    ApplePayDomainRetrieveParams as ApplePayDomainRetrieveParams,
)
from stripe.params._application_fee_create_refund_params import (
    ApplicationFeeCreateRefundParams as ApplicationFeeCreateRefundParams,
)
from stripe.params._application_fee_list_params import (
    ApplicationFeeListParams as ApplicationFeeListParams,
)
from stripe.params._application_fee_list_refunds_params import (
    ApplicationFeeListRefundsParams as ApplicationFeeListRefundsParams,
)
from stripe.params._application_fee_modify_refund_params import (
    ApplicationFeeModifyRefundParams as ApplicationFeeModifyRefundParams,
)
from stripe.params._application_fee_refund_create_params import (
    ApplicationFeeRefundCreateParams as ApplicationFeeRefundCreateParams,
)
from stripe.params._application_fee_refund_list_params import (
    ApplicationFeeRefundListParams as ApplicationFeeRefundListParams,
)
from stripe.params._application_fee_refund_params import (
    ApplicationFeeRefundParams as ApplicationFeeRefundParams,
)
from stripe.params._application_fee_refund_retrieve_params import (
    ApplicationFeeRefundRetrieveParams as ApplicationFeeRefundRetrieveParams,
)
from stripe.params._application_fee_refund_update_params import (
    ApplicationFeeRefundUpdateParams as ApplicationFeeRefundUpdateParams,
)
from stripe.params._application_fee_retrieve_params import (
    ApplicationFeeRetrieveParams as ApplicationFeeRetrieveParams,
)
from stripe.params._application_fee_retrieve_refund_params import (
    ApplicationFeeRetrieveRefundParams as ApplicationFeeRetrieveRefundParams,
)
from stripe.params._balance_retrieve_params import (
    BalanceRetrieveParams as BalanceRetrieveParams,
)
from stripe.params._balance_settings_modify_params import (
    BalanceSettingsModifyParams as BalanceSettingsModifyParams,
)
from stripe.params._balance_settings_retrieve_params import (
    BalanceSettingsRetrieveParams as BalanceSettingsRetrieveParams,
)
from stripe.params._balance_settings_update_params import (
    BalanceSettingsUpdateParams as BalanceSettingsUpdateParams,
)
from stripe.params._balance_transaction_list_params import (
    BalanceTransactionListParams as BalanceTransactionListParams,
)
from stripe.params._balance_transaction_retrieve_params import (
    BalanceTransactionRetrieveParams as BalanceTransactionRetrieveParams,
)
from stripe.params._bank_account_delete_params import (
    BankAccountDeleteParams as BankAccountDeleteParams,
)
from stripe.params._card_delete_params import (
    CardDeleteParams as CardDeleteParams,
)
from stripe.params._charge_capture_params import (
    ChargeCaptureParams as ChargeCaptureParams,
)
from stripe.params._charge_create_params import (
    ChargeCreateParams as ChargeCreateParams,
)
from stripe.params._charge_list_params import (
    ChargeListParams as ChargeListParams,
)
from stripe.params._charge_list_refunds_params import (
    ChargeListRefundsParams as ChargeListRefundsParams,
)
from stripe.params._charge_modify_params import (
    ChargeModifyParams as ChargeModifyParams,
)
from stripe.params._charge_retrieve_params import (
    ChargeRetrieveParams as ChargeRetrieveParams,
)
from stripe.params._charge_retrieve_refund_params import (
    ChargeRetrieveRefundParams as ChargeRetrieveRefundParams,
)
from stripe.params._charge_search_params import (
    ChargeSearchParams as ChargeSearchParams,
)
from stripe.params._charge_update_params import (
    ChargeUpdateParams as ChargeUpdateParams,
)
from stripe.params._confirmation_token_create_params import (
    ConfirmationTokenCreateParams as ConfirmationTokenCreateParams,
)
from stripe.params._confirmation_token_retrieve_params import (
    ConfirmationTokenRetrieveParams as ConfirmationTokenRetrieveParams,
)
from stripe.params._country_spec_list_params import (
    CountrySpecListParams as CountrySpecListParams,
)
from stripe.params._country_spec_retrieve_params import (
    CountrySpecRetrieveParams as CountrySpecRetrieveParams,
)
from stripe.params._coupon_create_params import (
    CouponCreateParams as CouponCreateParams,
)
from stripe.params._coupon_delete_params import (
    CouponDeleteParams as CouponDeleteParams,
)
from stripe.params._coupon_list_params import (
    CouponListParams as CouponListParams,
)
from stripe.params._coupon_modify_params import (
    CouponModifyParams as CouponModifyParams,
)
from stripe.params._coupon_retrieve_params import (
    CouponRetrieveParams as CouponRetrieveParams,
)
from stripe.params._coupon_update_params import (
    CouponUpdateParams as CouponUpdateParams,
)
from stripe.params._credit_note_create_params import (
    CreditNoteCreateParams as CreditNoteCreateParams,
)
from stripe.params._credit_note_line_item_list_params import (
    CreditNoteLineItemListParams as CreditNoteLineItemListParams,
)
from stripe.params._credit_note_list_lines_params import (
    CreditNoteListLinesParams as CreditNoteListLinesParams,
)
from stripe.params._credit_note_list_params import (
    CreditNoteListParams as CreditNoteListParams,
)
from stripe.params._credit_note_modify_params import (
    CreditNoteModifyParams as CreditNoteModifyParams,
)
from stripe.params._credit_note_preview_lines_list_params import (
    CreditNotePreviewLinesListParams as CreditNotePreviewLinesListParams,
)
from stripe.params._credit_note_preview_lines_params import (
    CreditNotePreviewLinesParams as CreditNotePreviewLinesParams,
)
from stripe.params._credit_note_preview_params import (
    CreditNotePreviewParams as CreditNotePreviewParams,
)
from stripe.params._credit_note_retrieve_params import (
    CreditNoteRetrieveParams as CreditNoteRetrieveParams,
)
from stripe.params._credit_note_update_params import (
    CreditNoteUpdateParams as CreditNoteUpdateParams,
)
from stripe.params._credit_note_void_credit_note_params import (
    CreditNoteVoidCreditNoteParams as CreditNoteVoidCreditNoteParams,
)
from stripe.params._customer_balance_transaction_create_params import (
    CustomerBalanceTransactionCreateParams as CustomerBalanceTransactionCreateParams,
)
from stripe.params._customer_balance_transaction_list_params import (
    CustomerBalanceTransactionListParams as CustomerBalanceTransactionListParams,
)
from stripe.params._customer_balance_transaction_retrieve_params import (
    CustomerBalanceTransactionRetrieveParams as CustomerBalanceTransactionRetrieveParams,
)
from stripe.params._customer_balance_transaction_update_params import (
    CustomerBalanceTransactionUpdateParams as CustomerBalanceTransactionUpdateParams,
)
from stripe.params._customer_cash_balance_retrieve_params import (
    CustomerCashBalanceRetrieveParams as CustomerCashBalanceRetrieveParams,
)
from stripe.params._customer_cash_balance_transaction_list_params import (
    CustomerCashBalanceTransactionListParams as CustomerCashBalanceTransactionListParams,
)
from stripe.params._customer_cash_balance_transaction_retrieve_params import (
    CustomerCashBalanceTransactionRetrieveParams as CustomerCashBalanceTransactionRetrieveParams,
)
from stripe.params._customer_cash_balance_update_params import (
    CustomerCashBalanceUpdateParams as CustomerCashBalanceUpdateParams,
)
from stripe.params._customer_create_balance_transaction_params import (
    CustomerCreateBalanceTransactionParams as CustomerCreateBalanceTransactionParams,
)
from stripe.params._customer_create_funding_instructions_params import (
    CustomerCreateFundingInstructionsParams as CustomerCreateFundingInstructionsParams,
)
from stripe.params._customer_create_params import (
    CustomerCreateParams as CustomerCreateParams,
)
from stripe.params._customer_create_source_params import (
    CustomerCreateSourceParams as CustomerCreateSourceParams,
)
from stripe.params._customer_create_tax_id_params import (
    CustomerCreateTaxIdParams as CustomerCreateTaxIdParams,
)
from stripe.params._customer_delete_discount_params import (
    CustomerDeleteDiscountParams as CustomerDeleteDiscountParams,
)
from stripe.params._customer_delete_params import (
    CustomerDeleteParams as CustomerDeleteParams,
)
from stripe.params._customer_delete_source_params import (
    CustomerDeleteSourceParams as CustomerDeleteSourceParams,
)
from stripe.params._customer_delete_tax_id_params import (
    CustomerDeleteTaxIdParams as CustomerDeleteTaxIdParams,
)
from stripe.params._customer_fund_cash_balance_params import (
    CustomerFundCashBalanceParams as CustomerFundCashBalanceParams,
)
from stripe.params._customer_funding_instructions_create_params import (
    CustomerFundingInstructionsCreateParams as CustomerFundingInstructionsCreateParams,
)
from stripe.params._customer_list_balance_transactions_params import (
    CustomerListBalanceTransactionsParams as CustomerListBalanceTransactionsParams,
)
from stripe.params._customer_list_cash_balance_transactions_params import (
    CustomerListCashBalanceTransactionsParams as CustomerListCashBalanceTransactionsParams,
)
from stripe.params._customer_list_params import (
    CustomerListParams as CustomerListParams,
)
from stripe.params._customer_list_payment_methods_params import (
    CustomerListPaymentMethodsParams as CustomerListPaymentMethodsParams,
)
from stripe.params._customer_list_sources_params import (
    CustomerListSourcesParams as CustomerListSourcesParams,
)
from stripe.params._customer_list_tax_ids_params import (
    CustomerListTaxIdsParams as CustomerListTaxIdsParams,
)
from stripe.params._customer_modify_balance_transaction_params import (
    CustomerModifyBalanceTransactionParams as CustomerModifyBalanceTransactionParams,
)
from stripe.params._customer_modify_cash_balance_params import (
    CustomerModifyCashBalanceParams as CustomerModifyCashBalanceParams,
)
from stripe.params._customer_modify_params import (
    CustomerModifyParams as CustomerModifyParams,
)
from stripe.params._customer_modify_source_params import (
    CustomerModifySourceParams as CustomerModifySourceParams,
)
from stripe.params._customer_payment_method_list_params import (
    CustomerPaymentMethodListParams as CustomerPaymentMethodListParams,
)
from stripe.params._customer_payment_method_retrieve_params import (
    CustomerPaymentMethodRetrieveParams as CustomerPaymentMethodRetrieveParams,
)
from stripe.params._customer_payment_source_create_params import (
    CustomerPaymentSourceCreateParams as CustomerPaymentSourceCreateParams,
)
from stripe.params._customer_payment_source_delete_params import (
    CustomerPaymentSourceDeleteParams as CustomerPaymentSourceDeleteParams,
)
from stripe.params._customer_payment_source_list_params import (
    CustomerPaymentSourceListParams as CustomerPaymentSourceListParams,
)
from stripe.params._customer_payment_source_retrieve_params import (
    CustomerPaymentSourceRetrieveParams as CustomerPaymentSourceRetrieveParams,
)
from stripe.params._customer_payment_source_update_params import (
    CustomerPaymentSourceUpdateParams as CustomerPaymentSourceUpdateParams,
)
from stripe.params._customer_payment_source_verify_params import (
    CustomerPaymentSourceVerifyParams as CustomerPaymentSourceVerifyParams,
)
from stripe.params._customer_retrieve_balance_transaction_params import (
    CustomerRetrieveBalanceTransactionParams as CustomerRetrieveBalanceTransactionParams,
)
from stripe.params._customer_retrieve_cash_balance_params import (
    CustomerRetrieveCashBalanceParams as CustomerRetrieveCashBalanceParams,
)
from stripe.params._customer_retrieve_cash_balance_transaction_params import (
    CustomerRetrieveCashBalanceTransactionParams as CustomerRetrieveCashBalanceTransactionParams,
)
from stripe.params._customer_retrieve_params import (
    CustomerRetrieveParams as CustomerRetrieveParams,
)
from stripe.params._customer_retrieve_payment_method_params import (
    CustomerRetrievePaymentMethodParams as CustomerRetrievePaymentMethodParams,
)
from stripe.params._customer_retrieve_source_params import (
    CustomerRetrieveSourceParams as CustomerRetrieveSourceParams,
)
from stripe.params._customer_retrieve_tax_id_params import (
    CustomerRetrieveTaxIdParams as CustomerRetrieveTaxIdParams,
)
from stripe.params._customer_search_params import (
    CustomerSearchParams as CustomerSearchParams,
)
from stripe.params._customer_session_create_params import (
    CustomerSessionCreateParams as CustomerSessionCreateParams,
)
from stripe.params._customer_tax_id_create_params import (
    CustomerTaxIdCreateParams as CustomerTaxIdCreateParams,
)
from stripe.params._customer_tax_id_delete_params import (
    CustomerTaxIdDeleteParams as CustomerTaxIdDeleteParams,
)
from stripe.params._customer_tax_id_list_params import (
    CustomerTaxIdListParams as CustomerTaxIdListParams,
)
from stripe.params._customer_tax_id_retrieve_params import (
    CustomerTaxIdRetrieveParams as CustomerTaxIdRetrieveParams,
)
from stripe.params._customer_update_params import (
    CustomerUpdateParams as CustomerUpdateParams,
)
from stripe.params._dispute_close_params import (
    DisputeCloseParams as DisputeCloseParams,
)
from stripe.params._dispute_list_params import (
    DisputeListParams as DisputeListParams,
)
from stripe.params._dispute_modify_params import (
    DisputeModifyParams as DisputeModifyParams,
)
from stripe.params._dispute_retrieve_params import (
    DisputeRetrieveParams as DisputeRetrieveParams,
)
from stripe.params._dispute_update_params import (
    DisputeUpdateParams as DisputeUpdateParams,
)
from stripe.params._ephemeral_key_create_params import (
    EphemeralKeyCreateParams as EphemeralKeyCreateParams,
)
from stripe.params._ephemeral_key_delete_params import (
    EphemeralKeyDeleteParams as EphemeralKeyDeleteParams,
)
from stripe.params._event_list_params import EventListParams as EventListParams
from stripe.params._event_retrieve_params import (
    EventRetrieveParams as EventRetrieveParams,
)
from stripe.params._exchange_rate_list_params import (
    ExchangeRateListParams as ExchangeRateListParams,
)
from stripe.params._exchange_rate_retrieve_params import (
    ExchangeRateRetrieveParams as ExchangeRateRetrieveParams,
)
from stripe.params._file_create_params import (
    FileCreateParams as FileCreateParams,
)
from stripe.params._file_link_create_params import (
    FileLinkCreateParams as FileLinkCreateParams,
)
from stripe.params._file_link_list_params import (
    FileLinkListParams as FileLinkListParams,
)
from stripe.params._file_link_modify_params import (
    FileLinkModifyParams as FileLinkModifyParams,
)
from stripe.params._file_link_retrieve_params import (
    FileLinkRetrieveParams as FileLinkRetrieveParams,
)
from stripe.params._file_link_update_params import (
    FileLinkUpdateParams as FileLinkUpdateParams,
)
from stripe.params._file_list_params import FileListParams as FileListParams
from stripe.params._file_retrieve_params import (
    FileRetrieveParams as FileRetrieveParams,
)
from stripe.params._invoice_add_lines_params import (
    InvoiceAddLinesParams as InvoiceAddLinesParams,
)
from stripe.params._invoice_attach_payment_params import (
    InvoiceAttachPaymentParams as InvoiceAttachPaymentParams,
)
from stripe.params._invoice_create_params import (
    InvoiceCreateParams as InvoiceCreateParams,
)
from stripe.params._invoice_create_preview_params import (
    InvoiceCreatePreviewParams as InvoiceCreatePreviewParams,
)
from stripe.params._invoice_delete_params import (
    InvoiceDeleteParams as InvoiceDeleteParams,
)
from stripe.params._invoice_finalize_invoice_params import (
    InvoiceFinalizeInvoiceParams as InvoiceFinalizeInvoiceParams,
)
from stripe.params._invoice_item_create_params import (
    InvoiceItemCreateParams as InvoiceItemCreateParams,
)
from stripe.params._invoice_item_delete_params import (
    InvoiceItemDeleteParams as InvoiceItemDeleteParams,
)
from stripe.params._invoice_item_list_params import (
    InvoiceItemListParams as InvoiceItemListParams,
)
from stripe.params._invoice_item_modify_params import (
    InvoiceItemModifyParams as InvoiceItemModifyParams,
)
from stripe.params._invoice_item_retrieve_params import (
    InvoiceItemRetrieveParams as InvoiceItemRetrieveParams,
)
from stripe.params._invoice_item_update_params import (
    InvoiceItemUpdateParams as InvoiceItemUpdateParams,
)
from stripe.params._invoice_line_item_list_params import (
    InvoiceLineItemListParams as InvoiceLineItemListParams,
)
from stripe.params._invoice_line_item_update_params import (
    InvoiceLineItemUpdateParams as InvoiceLineItemUpdateParams,
)
from stripe.params._invoice_list_lines_params import (
    InvoiceListLinesParams as InvoiceListLinesParams,
)
from stripe.params._invoice_list_params import (
    InvoiceListParams as InvoiceListParams,
)
from stripe.params._invoice_mark_uncollectible_params import (
    InvoiceMarkUncollectibleParams as InvoiceMarkUncollectibleParams,
)
from stripe.params._invoice_modify_params import (
    InvoiceModifyParams as InvoiceModifyParams,
)
from stripe.params._invoice_pay_params import (
    InvoicePayParams as InvoicePayParams,
)
from stripe.params._invoice_payment_list_params import (
    InvoicePaymentListParams as InvoicePaymentListParams,
)
from stripe.params._invoice_payment_retrieve_params import (
    InvoicePaymentRetrieveParams as InvoicePaymentRetrieveParams,
)
from stripe.params._invoice_remove_lines_params import (
    InvoiceRemoveLinesParams as InvoiceRemoveLinesParams,
)
from stripe.params._invoice_rendering_template_archive_params import (
    InvoiceRenderingTemplateArchiveParams as InvoiceRenderingTemplateArchiveParams,
)
from stripe.params._invoice_rendering_template_list_params import (
    InvoiceRenderingTemplateListParams as InvoiceRenderingTemplateListParams,
)
from stripe.params._invoice_rendering_template_retrieve_params import (
    InvoiceRenderingTemplateRetrieveParams as InvoiceRenderingTemplateRetrieveParams,
)
from stripe.params._invoice_rendering_template_unarchive_params import (
    InvoiceRenderingTemplateUnarchiveParams as InvoiceRenderingTemplateUnarchiveParams,
)
from stripe.params._invoice_retrieve_params import (
    InvoiceRetrieveParams as InvoiceRetrieveParams,
)
from stripe.params._invoice_search_params import (
    InvoiceSearchParams as InvoiceSearchParams,
)
from stripe.params._invoice_send_invoice_params import (
    InvoiceSendInvoiceParams as InvoiceSendInvoiceParams,
)
from stripe.params._invoice_update_lines_params import (
    InvoiceUpdateLinesParams as InvoiceUpdateLinesParams,
)
from stripe.params._invoice_update_params import (
    InvoiceUpdateParams as InvoiceUpdateParams,
)
from stripe.params._invoice_void_invoice_params import (
    InvoiceVoidInvoiceParams as InvoiceVoidInvoiceParams,
)
from stripe.params._mandate_retrieve_params import (
    MandateRetrieveParams as MandateRetrieveParams,
)
from stripe.params._payment_intent_apply_customer_balance_params import (
    PaymentIntentApplyCustomerBalanceParams as PaymentIntentApplyCustomerBalanceParams,
)
from stripe.params._payment_intent_cancel_params import (
    PaymentIntentCancelParams as PaymentIntentCancelParams,
)
from stripe.params._payment_intent_capture_params import (
    PaymentIntentCaptureParams as PaymentIntentCaptureParams,
)
from stripe.params._payment_intent_confirm_params import (
    PaymentIntentConfirmParams as PaymentIntentConfirmParams,
)
from stripe.params._payment_intent_create_params import (
    PaymentIntentCreateParams as PaymentIntentCreateParams,
)
from stripe.params._payment_intent_increment_authorization_params import (
    PaymentIntentIncrementAuthorizationParams as PaymentIntentIncrementAuthorizationParams,
)
from stripe.params._payment_intent_list_params import (
    PaymentIntentListParams as PaymentIntentListParams,
)
from stripe.params._payment_intent_modify_params import (
    PaymentIntentModifyParams as PaymentIntentModifyParams,
)
from stripe.params._payment_intent_retrieve_params import (
    PaymentIntentRetrieveParams as PaymentIntentRetrieveParams,
)
from stripe.params._payment_intent_search_params import (
    PaymentIntentSearchParams as PaymentIntentSearchParams,
)
from stripe.params._payment_intent_update_params import (
    PaymentIntentUpdateParams as PaymentIntentUpdateParams,
)
from stripe.params._payment_intent_verify_microdeposits_params import (
    PaymentIntentVerifyMicrodepositsParams as PaymentIntentVerifyMicrodepositsParams,
)
from stripe.params._payment_link_create_params import (
    PaymentLinkCreateParams as PaymentLinkCreateParams,
)
from stripe.params._payment_link_line_item_list_params import (
    PaymentLinkLineItemListParams as PaymentLinkLineItemListParams,
)
from stripe.params._payment_link_list_line_items_params import (
    PaymentLinkListLineItemsParams as PaymentLinkListLineItemsParams,
)
from stripe.params._payment_link_list_params import (
    PaymentLinkListParams as PaymentLinkListParams,
)
from stripe.params._payment_link_modify_params import (
    PaymentLinkModifyParams as PaymentLinkModifyParams,
)
from stripe.params._payment_link_retrieve_params import (
    PaymentLinkRetrieveParams as PaymentLinkRetrieveParams,
)
from stripe.params._payment_link_update_params import (
    PaymentLinkUpdateParams as PaymentLinkUpdateParams,
)
from stripe.params._payment_method_attach_params import (
    PaymentMethodAttachParams as PaymentMethodAttachParams,
)
from stripe.params._payment_method_configuration_create_params import (
    PaymentMethodConfigurationCreateParams as PaymentMethodConfigurationCreateParams,
)
from stripe.params._payment_method_configuration_list_params import (
    PaymentMethodConfigurationListParams as PaymentMethodConfigurationListParams,
)
from stripe.params._payment_method_configuration_modify_params import (
    PaymentMethodConfigurationModifyParams as PaymentMethodConfigurationModifyParams,
)
from stripe.params._payment_method_configuration_retrieve_params import (
    PaymentMethodConfigurationRetrieveParams as PaymentMethodConfigurationRetrieveParams,
)
from stripe.params._payment_method_configuration_update_params import (
    PaymentMethodConfigurationUpdateParams as PaymentMethodConfigurationUpdateParams,
)
from stripe.params._payment_method_create_params import (
    PaymentMethodCreateParams as PaymentMethodCreateParams,
)
from stripe.params._payment_method_detach_params import (
    PaymentMethodDetachParams as PaymentMethodDetachParams,
)
from stripe.params._payment_method_domain_create_params import (
    PaymentMethodDomainCreateParams as PaymentMethodDomainCreateParams,
)
from stripe.params._payment_method_domain_list_params import (
    PaymentMethodDomainListParams as PaymentMethodDomainListParams,
)
from stripe.params._payment_method_domain_modify_params import (
    PaymentMethodDomainModifyParams as PaymentMethodDomainModifyParams,
)
from stripe.params._payment_method_domain_retrieve_params import (
    PaymentMethodDomainRetrieveParams as PaymentMethodDomainRetrieveParams,
)
from stripe.params._payment_method_domain_update_params import (
    PaymentMethodDomainUpdateParams as PaymentMethodDomainUpdateParams,
)
from stripe.params._payment_method_domain_validate_params import (
    PaymentMethodDomainValidateParams as PaymentMethodDomainValidateParams,
)
from stripe.params._payment_method_list_params import (
    PaymentMethodListParams as PaymentMethodListParams,
)
from stripe.params._payment_method_modify_params import (
    PaymentMethodModifyParams as PaymentMethodModifyParams,
)
from stripe.params._payment_method_retrieve_params import (
    PaymentMethodRetrieveParams as PaymentMethodRetrieveParams,
)
from stripe.params._payment_method_update_params import (
    PaymentMethodUpdateParams as PaymentMethodUpdateParams,
)
from stripe.params._payout_cancel_params import (
    PayoutCancelParams as PayoutCancelParams,
)
from stripe.params._payout_create_params import (
    PayoutCreateParams as PayoutCreateParams,
)
from stripe.params._payout_list_params import (
    PayoutListParams as PayoutListParams,
)
from stripe.params._payout_modify_params import (
    PayoutModifyParams as PayoutModifyParams,
)
from stripe.params._payout_retrieve_params import (
    PayoutRetrieveParams as PayoutRetrieveParams,
)
from stripe.params._payout_reverse_params import (
    PayoutReverseParams as PayoutReverseParams,
)
from stripe.params._payout_update_params import (
    PayoutUpdateParams as PayoutUpdateParams,
)
from stripe.params._plan_create_params import (
    PlanCreateParams as PlanCreateParams,
)
from stripe.params._plan_delete_params import (
    PlanDeleteParams as PlanDeleteParams,
)
from stripe.params._plan_list_params import PlanListParams as PlanListParams
from stripe.params._plan_modify_params import (
    PlanModifyParams as PlanModifyParams,
)
from stripe.params._plan_retrieve_params import (
    PlanRetrieveParams as PlanRetrieveParams,
)
from stripe.params._plan_update_params import (
    PlanUpdateParams as PlanUpdateParams,
)
from stripe.params._price_create_params import (
    PriceCreateParams as PriceCreateParams,
)
from stripe.params._price_list_params import PriceListParams as PriceListParams
from stripe.params._price_modify_params import (
    PriceModifyParams as PriceModifyParams,
)
from stripe.params._price_retrieve_params import (
    PriceRetrieveParams as PriceRetrieveParams,
)
from stripe.params._price_search_params import (
    PriceSearchParams as PriceSearchParams,
)
from stripe.params._price_update_params import (
    PriceUpdateParams as PriceUpdateParams,
)
from stripe.params._product_create_feature_params import (
    ProductCreateFeatureParams as ProductCreateFeatureParams,
)
from stripe.params._product_create_params import (
    ProductCreateParams as ProductCreateParams,
)
from stripe.params._product_delete_feature_params import (
    ProductDeleteFeatureParams as ProductDeleteFeatureParams,
)
from stripe.params._product_delete_params import (
    ProductDeleteParams as ProductDeleteParams,
)
from stripe.params._product_feature_create_params import (
    ProductFeatureCreateParams as ProductFeatureCreateParams,
)
from stripe.params._product_feature_delete_params import (
    ProductFeatureDeleteParams as ProductFeatureDeleteParams,
)
from stripe.params._product_feature_list_params import (
    ProductFeatureListParams as ProductFeatureListParams,
)
from stripe.params._product_feature_retrieve_params import (
    ProductFeatureRetrieveParams as ProductFeatureRetrieveParams,
)
from stripe.params._product_list_features_params import (
    ProductListFeaturesParams as ProductListFeaturesParams,
)
from stripe.params._product_list_params import (
    ProductListParams as ProductListParams,
)
from stripe.params._product_modify_params import (
    ProductModifyParams as ProductModifyParams,
)
from stripe.params._product_retrieve_feature_params import (
    ProductRetrieveFeatureParams as ProductRetrieveFeatureParams,
)
from stripe.params._product_retrieve_params import (
    ProductRetrieveParams as ProductRetrieveParams,
)
from stripe.params._product_search_params import (
    ProductSearchParams as ProductSearchParams,
)
from stripe.params._product_update_params import (
    ProductUpdateParams as ProductUpdateParams,
)
from stripe.params._promotion_code_create_params import (
    PromotionCodeCreateParams as PromotionCodeCreateParams,
)
from stripe.params._promotion_code_list_params import (
    PromotionCodeListParams as PromotionCodeListParams,
)
from stripe.params._promotion_code_modify_params import (
    PromotionCodeModifyParams as PromotionCodeModifyParams,
)
from stripe.params._promotion_code_retrieve_params import (
    PromotionCodeRetrieveParams as PromotionCodeRetrieveParams,
)
from stripe.params._promotion_code_update_params import (
    PromotionCodeUpdateParams as PromotionCodeUpdateParams,
)
from stripe.params._quote_accept_params import (
    QuoteAcceptParams as QuoteAcceptParams,
)
from stripe.params._quote_cancel_params import (
    QuoteCancelParams as QuoteCancelParams,
)
from stripe.params._quote_computed_upfront_line_items_list_params import (
    QuoteComputedUpfrontLineItemsListParams as QuoteComputedUpfrontLineItemsListParams,
)
from stripe.params._quote_create_params import (
    QuoteCreateParams as QuoteCreateParams,
)
from stripe.params._quote_finalize_quote_params import (
    QuoteFinalizeQuoteParams as QuoteFinalizeQuoteParams,
)
from stripe.params._quote_line_item_list_params import (
    QuoteLineItemListParams as QuoteLineItemListParams,
)
from stripe.params._quote_list_computed_upfront_line_items_params import (
    QuoteListComputedUpfrontLineItemsParams as QuoteListComputedUpfrontLineItemsParams,
)
from stripe.params._quote_list_line_items_params import (
    QuoteListLineItemsParams as QuoteListLineItemsParams,
)
from stripe.params._quote_list_params import QuoteListParams as QuoteListParams
from stripe.params._quote_modify_params import (
    QuoteModifyParams as QuoteModifyParams,
)
from stripe.params._quote_pdf_params import QuotePdfParams as QuotePdfParams
from stripe.params._quote_retrieve_params import (
    QuoteRetrieveParams as QuoteRetrieveParams,
)
from stripe.params._quote_update_params import (
    QuoteUpdateParams as QuoteUpdateParams,
)
from stripe.params._refund_cancel_params import (
    RefundCancelParams as RefundCancelParams,
)
from stripe.params._refund_create_params import (
    RefundCreateParams as RefundCreateParams,
)
from stripe.params._refund_expire_params import (
    RefundExpireParams as RefundExpireParams,
)
from stripe.params._refund_list_params import (
    RefundListParams as RefundListParams,
)
from stripe.params._refund_modify_params import (
    RefundModifyParams as RefundModifyParams,
)
from stripe.params._refund_retrieve_params import (
    RefundRetrieveParams as RefundRetrieveParams,
)
from stripe.params._refund_update_params import (
    RefundUpdateParams as RefundUpdateParams,
)
from stripe.params._review_approve_params import (
    ReviewApproveParams as ReviewApproveParams,
)
from stripe.params._review_list_params import (
    ReviewListParams as ReviewListParams,
)
from stripe.params._review_retrieve_params import (
    ReviewRetrieveParams as ReviewRetrieveParams,
)
from stripe.params._setup_attempt_list_params import (
    SetupAttemptListParams as SetupAttemptListParams,
)
from stripe.params._setup_intent_cancel_params import (
    SetupIntentCancelParams as SetupIntentCancelParams,
)
from stripe.params._setup_intent_confirm_params import (
    SetupIntentConfirmParams as SetupIntentConfirmParams,
)
from stripe.params._setup_intent_create_params import (
    SetupIntentCreateParams as SetupIntentCreateParams,
)
from stripe.params._setup_intent_list_params import (
    SetupIntentListParams as SetupIntentListParams,
)
from stripe.params._setup_intent_modify_params import (
    SetupIntentModifyParams as SetupIntentModifyParams,
)
from stripe.params._setup_intent_retrieve_params import (
    SetupIntentRetrieveParams as SetupIntentRetrieveParams,
)
from stripe.params._setup_intent_update_params import (
    SetupIntentUpdateParams as SetupIntentUpdateParams,
)
from stripe.params._setup_intent_verify_microdeposits_params import (
    SetupIntentVerifyMicrodepositsParams as SetupIntentVerifyMicrodepositsParams,
)
from stripe.params._shipping_rate_create_params import (
    ShippingRateCreateParams as ShippingRateCreateParams,
)
from stripe.params._shipping_rate_list_params import (
    ShippingRateListParams as ShippingRateListParams,
)
from stripe.params._shipping_rate_modify_params import (
    ShippingRateModifyParams as ShippingRateModifyParams,
)
from stripe.params._shipping_rate_retrieve_params import (
    ShippingRateRetrieveParams as ShippingRateRetrieveParams,
)
from stripe.params._shipping_rate_update_params import (
    ShippingRateUpdateParams as ShippingRateUpdateParams,
)
from stripe.params._source_create_params import (
    SourceCreateParams as SourceCreateParams,
)
from stripe.params._source_detach_params import (
    SourceDetachParams as SourceDetachParams,
)
from stripe.params._source_list_source_transactions_params import (
    SourceListSourceTransactionsParams as SourceListSourceTransactionsParams,
)
from stripe.params._source_modify_params import (
    SourceModifyParams as SourceModifyParams,
)
from stripe.params._source_retrieve_params import (
    SourceRetrieveParams as SourceRetrieveParams,
)
from stripe.params._source_transaction_list_params import (
    SourceTransactionListParams as SourceTransactionListParams,
)
from stripe.params._source_update_params import (
    SourceUpdateParams as SourceUpdateParams,
)
from stripe.params._source_verify_params import (
    SourceVerifyParams as SourceVerifyParams,
)
from stripe.params._subscription_cancel_params import (
    SubscriptionCancelParams as SubscriptionCancelParams,
)
from stripe.params._subscription_create_params import (
    SubscriptionCreateParams as SubscriptionCreateParams,
)
from stripe.params._subscription_delete_discount_params import (
    SubscriptionDeleteDiscountParams as SubscriptionDeleteDiscountParams,
)
from stripe.params._subscription_item_create_params import (
    SubscriptionItemCreateParams as SubscriptionItemCreateParams,
)
from stripe.params._subscription_item_delete_params import (
    SubscriptionItemDeleteParams as SubscriptionItemDeleteParams,
)
from stripe.params._subscription_item_list_params import (
    SubscriptionItemListParams as SubscriptionItemListParams,
)
from stripe.params._subscription_item_modify_params import (
    SubscriptionItemModifyParams as SubscriptionItemModifyParams,
)
from stripe.params._subscription_item_retrieve_params import (
    SubscriptionItemRetrieveParams as SubscriptionItemRetrieveParams,
)
from stripe.params._subscription_item_update_params import (
    SubscriptionItemUpdateParams as SubscriptionItemUpdateParams,
)
from stripe.params._subscription_list_params import (
    SubscriptionListParams as SubscriptionListParams,
)
from stripe.params._subscription_migrate_params import (
    SubscriptionMigrateParams as SubscriptionMigrateParams,
)
from stripe.params._subscription_modify_params import (
    SubscriptionModifyParams as SubscriptionModifyParams,
)
from stripe.params._subscription_resume_params import (
    SubscriptionResumeParams as SubscriptionResumeParams,
)
from stripe.params._subscription_retrieve_params import (
    SubscriptionRetrieveParams as SubscriptionRetrieveParams,
)
from stripe.params._subscription_schedule_cancel_params import (
    SubscriptionScheduleCancelParams as SubscriptionScheduleCancelParams,
)
from stripe.params._subscription_schedule_create_params import (
    SubscriptionScheduleCreateParams as SubscriptionScheduleCreateParams,
)
from stripe.params._subscription_schedule_list_params import (
    SubscriptionScheduleListParams as SubscriptionScheduleListParams,
)
from stripe.params._subscription_schedule_modify_params import (
    SubscriptionScheduleModifyParams as SubscriptionScheduleModifyParams,
)
from stripe.params._subscription_schedule_release_params import (
    SubscriptionScheduleReleaseParams as SubscriptionScheduleReleaseParams,
)
from stripe.params._subscription_schedule_retrieve_params import (
    SubscriptionScheduleRetrieveParams as SubscriptionScheduleRetrieveParams,
)
from stripe.params._subscription_schedule_update_params import (
    SubscriptionScheduleUpdateParams as SubscriptionScheduleUpdateParams,
)
from stripe.params._subscription_search_params import (
    SubscriptionSearchParams as SubscriptionSearchParams,
)
from stripe.params._subscription_update_params import (
    SubscriptionUpdateParams as SubscriptionUpdateParams,
)
from stripe.params._tax_code_list_params import (
    TaxCodeListParams as TaxCodeListParams,
)
from stripe.params._tax_code_retrieve_params import (
    TaxCodeRetrieveParams as TaxCodeRetrieveParams,
)
from stripe.params._tax_id_create_params import (
    TaxIdCreateParams as TaxIdCreateParams,
)
from stripe.params._tax_id_delete_params import (
    TaxIdDeleteParams as TaxIdDeleteParams,
)
from stripe.params._tax_id_list_params import (
    TaxIdListParams as TaxIdListParams,
)
from stripe.params._tax_id_retrieve_params import (
    TaxIdRetrieveParams as TaxIdRetrieveParams,
)
from stripe.params._tax_rate_create_params import (
    TaxRateCreateParams as TaxRateCreateParams,
)
from stripe.params._tax_rate_list_params import (
    TaxRateListParams as TaxRateListParams,
)
from stripe.params._tax_rate_modify_params import (
    TaxRateModifyParams as TaxRateModifyParams,
)
from stripe.params._tax_rate_retrieve_params import (
    TaxRateRetrieveParams as TaxRateRetrieveParams,
)
from stripe.params._tax_rate_update_params import (
    TaxRateUpdateParams as TaxRateUpdateParams,
)
from stripe.params._token_create_params import (
    TokenCreateParams as TokenCreateParams,
)
from stripe.params._token_retrieve_params import (
    TokenRetrieveParams as TokenRetrieveParams,
)
from stripe.params._topup_cancel_params import (
    TopupCancelParams as TopupCancelParams,
)
from stripe.params._topup_create_params import (
    TopupCreateParams as TopupCreateParams,
)
from stripe.params._topup_list_params import TopupListParams as TopupListParams
from stripe.params._topup_modify_params import (
    TopupModifyParams as TopupModifyParams,
)
from stripe.params._topup_retrieve_params import (
    TopupRetrieveParams as TopupRetrieveParams,
)
from stripe.params._topup_update_params import (
    TopupUpdateParams as TopupUpdateParams,
)
from stripe.params._transfer_create_params import (
    TransferCreateParams as TransferCreateParams,
)
from stripe.params._transfer_create_reversal_params import (
    TransferCreateReversalParams as TransferCreateReversalParams,
)
from stripe.params._transfer_list_params import (
    TransferListParams as TransferListParams,
)
from stripe.params._transfer_list_reversals_params import (
    TransferListReversalsParams as TransferListReversalsParams,
)
from stripe.params._transfer_modify_params import (
    TransferModifyParams as TransferModifyParams,
)
from stripe.params._transfer_modify_reversal_params import (
    TransferModifyReversalParams as TransferModifyReversalParams,
)
from stripe.params._transfer_retrieve_params import (
    TransferRetrieveParams as TransferRetrieveParams,
)
from stripe.params._transfer_retrieve_reversal_params import (
    TransferRetrieveReversalParams as TransferRetrieveReversalParams,
)
from stripe.params._transfer_reversal_create_params import (
    TransferReversalCreateParams as TransferReversalCreateParams,
)
from stripe.params._transfer_reversal_list_params import (
    TransferReversalListParams as TransferReversalListParams,
)
from stripe.params._transfer_reversal_retrieve_params import (
    TransferReversalRetrieveParams as TransferReversalRetrieveParams,
)
from stripe.params._transfer_reversal_update_params import (
    TransferReversalUpdateParams as TransferReversalUpdateParams,
)
from stripe.params._transfer_update_params import (
    TransferUpdateParams as TransferUpdateParams,
)
from stripe.params._webhook_endpoint_create_params import (
    WebhookEndpointCreateParams as WebhookEndpointCreateParams,
)
from stripe.params._webhook_endpoint_delete_params import (
    WebhookEndpointDeleteParams as WebhookEndpointDeleteParams,
)
from stripe.params._webhook_endpoint_list_params import (
    WebhookEndpointListParams as WebhookEndpointListParams,
)
from stripe.params._webhook_endpoint_modify_params import (
    WebhookEndpointModifyParams as WebhookEndpointModifyParams,
)
from stripe.params._webhook_endpoint_retrieve_params import (
    WebhookEndpointRetrieveParams as WebhookEndpointRetrieveParams,
)
from stripe.params._webhook_endpoint_update_params import (
    WebhookEndpointUpdateParams as WebhookEndpointUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.billing._alert_activate_params import (
    AlertActivateParams as AlertActivateParams,
)
from stripe.params.billing._alert_archive_params import (
    AlertArchiveParams as AlertArchiveParams,
)
from stripe.params.billing._alert_create_params import (
    AlertCreateParams as AlertCreateParams,
)
from stripe.params.billing._alert_deactivate_params import (
    AlertDeactivateParams as AlertDeactivateParams,
)
from stripe.params.billing._alert_list_params import (
    AlertListParams as AlertListParams,
)
from stripe.params.billing._alert_retrieve_params import (
    AlertRetrieveParams as AlertRetrieveParams,
)
from stripe.params.billing._credit_balance_summary_retrieve_params import (
    CreditBalanceSummaryRetrieveParams as CreditBalanceSummaryRetrieveParams,
)
from stripe.params.billing._credit_balance_transaction_list_params import (
    CreditBalanceTransactionListParams as CreditBalanceTransactionListParams,
)
from stripe.params.billing._credit_balance_transaction_retrieve_params import (
    CreditBalanceTransactionRetrieveParams as CreditBalanceTransactionRetrieveParams,
)
from stripe.params.billing._credit_grant_create_params import (
    CreditGrantCreateParams as CreditGrantCreateParams,
)
from stripe.params.billing._credit_grant_expire_params import (
    CreditGrantExpireParams as CreditGrantExpireParams,
)
from stripe.params.billing._credit_grant_list_params import (
    CreditGrantListParams as CreditGrantListParams,
)
from stripe.params.billing._credit_grant_modify_params import (
    CreditGrantModifyParams as CreditGrantModifyParams,
)
from stripe.params.billing._credit_grant_retrieve_params import (
    CreditGrantRetrieveParams as CreditGrantRetrieveParams,
)
from stripe.params.billing._credit_grant_update_params import (
    CreditGrantUpdateParams as CreditGrantUpdateParams,
)
from stripe.params.billing._credit_grant_void_grant_params import (
    CreditGrantVoidGrantParams as CreditGrantVoidGrantParams,
)
from stripe.params.billing._meter_create_params import (
    MeterCreateParams as MeterCreateParams,
)
from stripe.params.billing._meter_deactivate_params import (
    MeterDeactivateParams as MeterDeactivateParams,
)
from stripe.params.billing._meter_event_adjustment_create_params import (
    MeterEventAdjustmentCreateParams as MeterEventAdjustmentCreateParams,
)
from stripe.params.billing._meter_event_create_params import (
    MeterEventCreateParams as MeterEventCreateParams,
)
from stripe.params.billing._meter_event_summary_list_params import (
    MeterEventSummaryListParams as MeterEventSummaryListParams,
)
from stripe.params.billing._meter_list_event_summaries_params import (
    MeterListEventSummariesParams as MeterListEventSummariesParams,
)
from stripe.params.billing._meter_list_params import (
    MeterListParams as MeterListParams,
)
from stripe.params.billing._meter_modify_params import (
    MeterModifyParams as MeterModifyParams,
)
from stripe.params.billing._meter_reactivate_params import (
    MeterReactivateParams as MeterReactivateParams,
)
from stripe.params.billing._meter_retrieve_params import (
    MeterRetrieveParams as MeterRetrieveParams,
)
from stripe.params.billing._meter_update_params import (
    MeterUpdateParams as MeterUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.issuing._authorization_approve_params import (
    AuthorizationApproveParams as AuthorizationApproveParams,
)
from stripe.params.issuing._authorization_capture_params import (
    AuthorizationCaptureParams as AuthorizationCaptureParams,
)
from stripe.params.issuing._authorization_create_params import (
    AuthorizationCreateParams as AuthorizationCreateParams,
)
from stripe.params.issuing._authorization_decline_params import (
    AuthorizationDeclineParams as AuthorizationDeclineParams,
)
from stripe.params.issuing._authorization_expire_params import (
    AuthorizationExpireParams as AuthorizationExpireParams,
)
from stripe.params.issuing._authorization_finalize_amount_params import (
    AuthorizationFinalizeAmountParams as AuthorizationFinalizeAmountParams,
)
from stripe.params.issuing._authorization_increment_params import (
    AuthorizationIncrementParams as AuthorizationIncrementParams,
)
from stripe.params.issuing._authorization_list_params import (
    AuthorizationListParams as AuthorizationListParams,
)
from stripe.params.issuing._authorization_modify_params import (
    AuthorizationModifyParams as AuthorizationModifyParams,
)
from stripe.params.issuing._authorization_respond_params import (
    AuthorizationRespondParams as AuthorizationRespondParams,
)
from stripe.params.issuing._authorization_retrieve_params import (
    AuthorizationRetrieveParams as AuthorizationRetrieveParams,
)
from stripe.params.issuing._authorization_reverse_params import (
    AuthorizationReverseParams as AuthorizationReverseParams,
)
from stripe.params.issuing._authorization_update_params import (
    AuthorizationUpdateParams as AuthorizationUpdateParams,
)
from stripe.params.issuing._card_create_params import (
    CardCreateParams as CardCreateParams,
)
from stripe.params.issuing._card_deliver_card_params import (
    CardDeliverCardParams as CardDeliverCardParams,
)
from stripe.params.issuing._card_fail_card_params import (
    CardFailCardParams as CardFailCardParams,
)
from stripe.params.issuing._card_list_params import (
    CardListParams as CardListParams,
)
from stripe.params.issuing._card_modify_params import (
    CardModifyParams as CardModifyParams,
)
from stripe.params.issuing._card_retrieve_params import (
    CardRetrieveParams as CardRetrieveParams,
)
from stripe.params.issuing._card_return_card_params import (
    CardReturnCardParams as CardReturnCardParams,
)
from stripe.params.issuing._card_ship_card_params import (
    CardShipCardParams as CardShipCardParams,
)
from stripe.params.issuing._card_submit_card_params import (
    CardSubmitCardParams as CardSubmitCardParams,
)
from stripe.params.issuing._card_update_params import (
    CardUpdateParams as CardUpdateParams,
)
from stripe.params.issuing._cardholder_create_params import (
    CardholderCreateParams as CardholderCreateParams,
)
from stripe.params.issuing._cardholder_list_params import (
    CardholderListParams as CardholderListParams,
)
from stripe.params.issuing._cardholder_modify_params import (
    CardholderModifyParams as CardholderModifyParams,
)
from stripe.params.issuing._cardholder_retrieve_params import (
    CardholderRetrieveParams as CardholderRetrieveParams,
)
from stripe.params.issuing._cardholder_update_params import (
    CardholderUpdateParams as CardholderUpdateParams,
)
from stripe.params.issuing._dispute_create_params import (
    DisputeCreateParams as DisputeCreateParams,
)
from stripe.params.issuing._dispute_list_params import (
    DisputeListParams as DisputeListParams,
)
from stripe.params.issuing._dispute_modify_params import (
    DisputeModifyParams as DisputeModifyParams,
)
from stripe.params.issuing._dispute_retrieve_params import (
    DisputeRetrieveParams as DisputeRetrieveParams,
)
from stripe.params.issuing._dispute_submit_params import (
    DisputeSubmitParams as DisputeSubmitParams,
)
from stripe.params.issuing._dispute_update_params import (
    DisputeUpdateParams as DisputeUpdateParams,
)
from stripe.params.issuing._personalization_design_activate_params import (
    PersonalizationDesignActivateParams as PersonalizationDesignActivateParams,
)
from stripe.params.issuing._personalization_design_create_params import (
    PersonalizationDesignCreateParams as PersonalizationDesignCreateParams,
)
from stripe.params.issuing._personalization_design_deactivate_params import (
    PersonalizationDesignDeactivateParams as PersonalizationDesignDeactivateParams,
)
from stripe.params.issuing._personalization_design_list_params import (
    PersonalizationDesignListParams as PersonalizationDesignListParams,
)
from stripe.params.issuing._personalization_design_modify_params import (
    PersonalizationDesignModifyParams as PersonalizationDesignModifyParams,
)
from stripe.params.issuing._personalization_design_reject_params import (
    PersonalizationDesignRejectParams as PersonalizationDesignRejectParams,
)
from stripe.params.issuing._personalization_design_retrieve_params import (
    PersonalizationDesignRetrieveParams as PersonalizationDesignRetrieveParams,
)
from stripe.params.issuing._personalization_design_update_params import (
    PersonalizationDesignUpdateParams as PersonalizationDesignUpdateParams,
)
from stripe.params.issuing._physical_bundle_list_params import (
    PhysicalBundleListParams as PhysicalBundleListParams,
)
from stripe.params.issuing._physical_bundle_retrieve_params import (
    PhysicalBundleRetrieveParams as PhysicalBundleRetrieveParams,
)
from stripe.params.issuing._token_list_params import (
    TokenListParams as TokenListParams,
)
from stripe.params.issuing._token_modify_params import (
    TokenModifyParams as TokenModifyParams,
)
from stripe.params.issuing._token_retrieve_params import (
    TokenRetrieveParams as TokenRetrieveParams,
)
from stripe.params.issuing._token_update_params import (
    TokenUpdateParams as TokenUpdateParams,
)
from stripe.params.issuing._transaction_create_force_capture_params import (
    TransactionCreateForceCaptureParams as TransactionCreateForceCaptureParams,
)
from stripe.params.issuing._transaction_create_unlinked_refund_params import (
    TransactionCreateUnlinkedRefundParams as TransactionCreateUnlinkedRefundParams,
)
from stripe.params.issuing._transaction_list_params import (
    TransactionListParams as TransactionListParams,
)
from stripe.params.issuing._transaction_modify_params import (
    TransactionModifyParams as TransactionModifyParams,
)
from stripe.params.issuing._transaction_refund_params import (
    TransactionRefundParams as TransactionRefundParams,
)
from stripe.params.issuing._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)
from stripe.params.issuing._transaction_update_params import (
    TransactionUpdateParams as TransactionUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.terminal._reader import Reader
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.terminal._reader_cancel_action_params import (
        ReaderCancelActionParams,
    )
    from stripe.params.terminal._reader_collect_inputs_params import (
        ReaderCollectInputsParams,
    )
    from stripe.params.terminal._reader_collect_payment_method_params import (
        ReaderCollectPaymentMethodParams,
    )
    from stripe.params.terminal._reader_confirm_payment_intent_params import (
        ReaderConfirmPaymentIntentParams,
    )
    from stripe.params.terminal._reader_create_params import ReaderCreateParams
    from stripe.params.terminal._reader_delete_params import ReaderDeleteParams
    from stripe.params.terminal._reader_list_params import ReaderListParams
    from stripe.params.terminal._reader_process_payment_intent_params import (
        ReaderProcessPaymentIntentParams,
    )
    from stripe.params.terminal._reader_process_setup_intent_params import (
        ReaderProcessSetupIntentParams,
    )
    from stripe.params.terminal._reader_refund_payment_params import (
        ReaderRefundPaymentParams,
    )
    from stripe.params.terminal._reader_retrieve_params import (
        ReaderRetrieveParams,
    )
    from stripe.params.terminal._reader_set_reader_display_params import (
        ReaderSetReaderDisplayParams,
    )
    from stripe.params.terminal._reader_update_params import ReaderUpdateParams


class ReaderService(StripeService):
    def delete(
        self,
        reader: str,
        params: Optional["ReaderDeleteParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Deletes a Reader object.
        """
        return cast(
            Reader,
            self._request(
                "delete",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def delete_async(
        self,
        reader: str,
        params: Optional["ReaderDeleteParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Deletes a Reader object.
        """
        return cast(
            Reader,
            await self._request_async(
                "delete",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        reader: str,
        params: Optional["ReaderRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Retrieves a Reader object.
        """
        return cast(
            Reader,
            self._request(
                "get",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        reader: str,
        params: Optional["ReaderRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Retrieves a Reader object.
        """
        return cast(
            Reader,
            await self._request_async(
                "get",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        reader: str,
        params: Optional["ReaderUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        reader: str,
        params: Optional["ReaderUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def list(
        self,
        params: Optional["ReaderListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Reader]:
        """
        Returns a list of Reader objects.
        """
        return cast(
            ListObject[Reader],
            self._request(
                "get",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["ReaderListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Reader]:
        """
        Returns a list of Reader objects.
        """
        return cast(
            ListObject[Reader],
            await self._request_async(
                "get",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "ReaderCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Creates a new Reader object.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "ReaderCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Creates a new Reader object.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def cancel_action(
        self,
        reader: str,
        params: Optional["ReaderCancelActionParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Cancels the current reader action.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/cancel_action".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def cancel_action_async(
        self,
        reader: str,
        params: Optional["ReaderCancelActionParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Cancels the current reader action.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/cancel_action".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def collect_inputs(
        self,
        reader: str,
        params: "ReaderCollectInputsParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates an input collection flow on a Reader.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/collect_inputs".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def collect_inputs_async(
        self,
        reader: str,
        params: "ReaderCollectInputsParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates an input collection flow on a Reader.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/collect_inputs".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def collect_payment_method(
        self,
        reader: str,
        params: "ReaderCollectPaymentMethodParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/collect_payment_method".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def collect_payment_method_async(
        self,
        reader: str,
        params: "ReaderCollectPaymentMethodParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/collect_payment_method".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def confirm_payment_intent(
        self,
        reader: str,
        params: "ReaderConfirmPaymentIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Finalizes a payment on a Reader.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/confirm_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def confirm_payment_intent_async(
        self,
        reader: str,
        params: "ReaderConfirmPaymentIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Finalizes a payment on a Reader.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/confirm_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def process_payment_intent(
        self,
        reader: str,
        params: "ReaderProcessPaymentIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a payment flow on a Reader.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/process_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def process_payment_intent_async(
        self,
        reader: str,
        params: "ReaderProcessPaymentIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a payment flow on a Reader.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/process_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def process_setup_intent(
        self,
        reader: str,
        params: "ReaderProcessSetupIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a setup intent flow on a Reader.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/process_setup_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def process_setup_intent_async(
        self,
        reader: str,
        params: "ReaderProcessSetupIntentParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a setup intent flow on a Reader.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/process_setup_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def refund_payment(
        self,
        reader: str,
        params: Optional["ReaderRefundPaymentParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a refund on a Reader
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/refund_payment".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def refund_payment_async(
        self,
        reader: str,
        params: Optional["ReaderRefundPaymentParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Initiates a refund on a Reader
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/refund_payment".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def set_reader_display(
        self,
        reader: str,
        params: "ReaderSetReaderDisplayParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Sets reader display to show cart details.
        """
        return cast(
            Reader,
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/set_reader_display".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def set_reader_display_async(
        self,
        reader: str,
        params: "ReaderSetReaderDisplayParams",
        options: Optional[RequestOptions] = None,
    ) -> Reader:
        """
        Sets reader display to show cart details.
        """
        return cast(
            Reader,
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/set_reader_display".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.checkout._session_create_params import (
    SessionCreateParams as SessionCreateParams,
)
from stripe.params.checkout._session_expire_params import (
    SessionExpireParams as SessionExpireParams,
)
from stripe.params.checkout._session_line_item_list_params import (
    SessionLineItemListParams as SessionLineItemListParams,
)
from stripe.params.checkout._session_list_line_items_params import (
    SessionListLineItemsParams as SessionListLineItemsParams,
)
from stripe.params.checkout._session_list_params import (
    SessionListParams as SessionListParams,
)
from stripe.params.checkout._session_modify_params import (
    SessionModifyParams as SessionModifyParams,
)
from stripe.params.checkout._session_retrieve_params import (
    SessionRetrieveParams as SessionRetrieveParams,
)
from stripe.params.checkout._session_update_params import (
    SessionUpdateParams as SessionUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.terminal._configuration_create_params import (
    ConfigurationCreateParams as ConfigurationCreateParams,
)
from stripe.params.terminal._configuration_delete_params import (
    ConfigurationDeleteParams as ConfigurationDeleteParams,
)
from stripe.params.terminal._configuration_list_params import (
    ConfigurationListParams as ConfigurationListParams,
)
from stripe.params.terminal._configuration_modify_params import (
    ConfigurationModifyParams as ConfigurationModifyParams,
)
from stripe.params.terminal._configuration_retrieve_params import (
    ConfigurationRetrieveParams as ConfigurationRetrieveParams,
)
from stripe.params.terminal._configuration_update_params import (
    ConfigurationUpdateParams as ConfigurationUpdateParams,
)
from stripe.params.terminal._connection_token_create_params import (
    ConnectionTokenCreateParams as ConnectionTokenCreateParams,
)
from stripe.params.terminal._location_create_params import (
    LocationCreateParams as LocationCreateParams,
)
from stripe.params.terminal._location_delete_params import (
    LocationDeleteParams as LocationDeleteParams,
)
from stripe.params.terminal._location_list_params import (
    LocationListParams as LocationListParams,
)
from stripe.params.terminal._location_modify_params import (
    LocationModifyParams as LocationModifyParams,
)
from stripe.params.terminal._location_retrieve_params import (
    LocationRetrieveParams as LocationRetrieveParams,
)
from stripe.params.terminal._location_update_params import (
    LocationUpdateParams as LocationUpdateParams,
)
from stripe.params.terminal._reader_cancel_action_params import (
    ReaderCancelActionParams as ReaderCancelActionParams,
)
from stripe.params.terminal._reader_collect_inputs_params import (
    ReaderCollectInputsParams as ReaderCollectInputsParams,
)
from stripe.params.terminal._reader_collect_payment_method_params import (
    ReaderCollectPaymentMethodParams as ReaderCollectPaymentMethodParams,
)
from stripe.params.terminal._reader_confirm_payment_intent_params import (
    ReaderConfirmPaymentIntentParams as ReaderConfirmPaymentIntentParams,
)
from stripe.params.terminal._reader_create_params import (
    ReaderCreateParams as ReaderCreateParams,
)
from stripe.params.terminal._reader_delete_params import (
    ReaderDeleteParams as ReaderDeleteParams,
)
from stripe.params.terminal._reader_list_params import (
    ReaderListParams as ReaderListParams,
)
from stripe.params.terminal._reader_modify_params import (
    ReaderModifyParams as ReaderModifyParams,
)
from stripe.params.terminal._reader_present_payment_method_params import (
    ReaderPresentPaymentMethodParams as ReaderPresentPaymentMethodParams,
)
from stripe.params.terminal._reader_process_payment_intent_params import (
    ReaderProcessPaymentIntentParams as ReaderProcessPaymentIntentParams,
)
from stripe.params.terminal._reader_process_setup_intent_params import (
    ReaderProcessSetupIntentParams as ReaderProcessSetupIntentParams,
)
from stripe.params.terminal._reader_refund_payment_params import (
    ReaderRefundPaymentParams as ReaderRefundPaymentParams,
)
from stripe.params.terminal._reader_retrieve_params import (
    ReaderRetrieveParams as ReaderRetrieveParams,
)
from stripe.params.terminal._reader_set_reader_display_params import (
    ReaderSetReaderDisplayParams as ReaderSetReaderDisplayParams,
)
from stripe.params.terminal._reader_succeed_input_collection_params import (
    ReaderSucceedInputCollectionParams as ReaderSucceedInputCollectionParams,
)
from stripe.params.terminal._reader_timeout_input_collection_params import (
    ReaderTimeoutInputCollectionParams as ReaderTimeoutInputCollectionParams,
)
from stripe.params.terminal._reader_update_params import (
    ReaderUpdateParams as ReaderUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.entitlements._active_entitlement_list_params import (
    ActiveEntitlementListParams as ActiveEntitlementListParams,
)
from stripe.params.entitlements._active_entitlement_retrieve_params import (
    ActiveEntitlementRetrieveParams as ActiveEntitlementRetrieveParams,
)
from stripe.params.entitlements._feature_create_params import (
    FeatureCreateParams as FeatureCreateParams,
)
from stripe.params.entitlements._feature_list_params import (
    FeatureListParams as FeatureListParams,
)
from stripe.params.entitlements._feature_modify_params import (
    FeatureModifyParams as FeatureModifyParams,
)
from stripe.params.entitlements._feature_retrieve_params import (
    FeatureRetrieveParams as FeatureRetrieveParams,
)
from stripe.params.entitlements._feature_update_params import (
    FeatureUpdateParams as FeatureUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._line_item import LineItem
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.checkout._session_line_item_list_params import (
        SessionLineItemListParams,
    )


class SessionLineItemService(StripeService):
    def list(
        self,
        session: str,
        params: Optional["SessionLineItemListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[LineItem]:
        """
        When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
        """
        return cast(
            ListObject[LineItem],
            self._request(
                "get",
                "/v1/checkout/sessions/{session}/line_items".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        session: str,
        params: Optional["SessionLineItemListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[LineItem]:
        """
        When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
        """
        return cast(
            ListObject[LineItem],
            await self._request_async(
                "get",
                "/v1/checkout/sessions/{session}/line_items".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.billing._meter_event_summary import MeterEventSummary
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.billing._meter_event_summary_list_params import (
        MeterEventSummaryListParams,
    )


class MeterEventSummaryService(StripeService):
    def list(
        self,
        id: str,
        params: "MeterEventSummaryListParams",
        options: Optional[RequestOptions] = None,
    ) -> ListObject[MeterEventSummary]:
        """
        Retrieve a list of billing meter event summaries.
        """
        return cast(
            ListObject[MeterEventSummary],
            self._request(
                "get",
                "/v1/billing/meters/{id}/event_summaries".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        id: str,
        params: "MeterEventSummaryListParams",
        options: Optional[RequestOptions] = None,
    ) -> ListObject[MeterEventSummary]:
        """
        Retrieve a list of billing meter event summaries.
        """
        return cast(
            ListObject[MeterEventSummary],
            await self._request_async(
                "get",
                "/v1/billing/meters/{id}/event_summaries".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class PaymentIntentCaptureParams(RequestOptions):
    amount_to_capture: NotRequired[int]
    """
    The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full `amount_capturable` if it's not provided.
    """
    application_fee_amount: NotRequired[int]
    """
    The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](https://stripe.com/docs/payments/connected-accounts).
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    final_capture: NotRequired[bool]
    """
    Defaults to `true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they're captured in future requests. You can only use this setting when [multicapture](https://stripe.com/docs/payments/multicapture) is available for PaymentIntents.
    """
    metadata: NotRequired["Literal['']|Dict[str, str]"]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    statement_descriptor: NotRequired[str]
    """
    Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](https://docs.stripe.com/get-started/account/statement-descriptors).

    Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](https://docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
    """
    statement_descriptor_suffix: NotRequired[str]
    """
    Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement.
    """
    transfer_data: NotRequired["PaymentIntentCaptureParamsTransferData"]
    """
    The parameters that you can use to automatically create a transfer after the payment
    is captured. Learn more about the [use case for connected accounts](https://stripe.com/docs/payments/connected-accounts).
    """


class PaymentIntentCaptureParamsTransferData(TypedDict):
    amount: NotRequired[int]
    """
    The amount that will be transferred automatically when a charge succeeds.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers import (
    issuing as issuing,
    terminal as terminal,
    treasury as treasury,
)
from stripe.params.test_helpers._confirmation_token_create_params import (
    ConfirmationTokenCreateParams as ConfirmationTokenCreateParams,
)
from stripe.params.test_helpers._customer_fund_cash_balance_params import (
    CustomerFundCashBalanceParams as CustomerFundCashBalanceParams,
)
from stripe.params.test_helpers._refund_expire_params import (
    RefundExpireParams as RefundExpireParams,
)
from stripe.params.test_helpers._test_clock_advance_params import (
    TestClockAdvanceParams as TestClockAdvanceParams,
)
from stripe.params.test_helpers._test_clock_create_params import (
    TestClockCreateParams as TestClockCreateParams,
)
from stripe.params.test_helpers._test_clock_delete_params import (
    TestClockDeleteParams as TestClockDeleteParams,
)
from stripe.params.test_helpers._test_clock_list_params import (
    TestClockListParams as TestClockListParams,
)
from stripe.params.test_helpers._test_clock_retrieve_params import (
    TestClockRetrieveParams as TestClockRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.climate._order_cancel_params import (
    OrderCancelParams as OrderCancelParams,
)
from stripe.params.climate._order_create_params import (
    OrderCreateParams as OrderCreateParams,
)
from stripe.params.climate._order_list_params import (
    OrderListParams as OrderListParams,
)
from stripe.params.climate._order_modify_params import (
    OrderModifyParams as OrderModifyParams,
)
from stripe.params.climate._order_retrieve_params import (
    OrderRetrieveParams as OrderRetrieveParams,
)
from stripe.params.climate._order_update_params import (
    OrderUpdateParams as OrderUpdateParams,
)
from stripe.params.climate._product_list_params import (
    ProductListParams as ProductListParams,
)
from stripe.params.climate._product_retrieve_params import (
    ProductRetrieveParams as ProductRetrieveParams,
)
from stripe.params.climate._supplier_list_params import (
    SupplierListParams as SupplierListParams,
)
from stripe.params.climate._supplier_retrieve_params import (
    SupplierRetrieveParams as SupplierRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.billing_portal._configuration_create_params import (
    ConfigurationCreateParams as ConfigurationCreateParams,
)
from stripe.params.billing_portal._configuration_list_params import (
    ConfigurationListParams as ConfigurationListParams,
)
from stripe.params.billing_portal._configuration_modify_params import (
    ConfigurationModifyParams as ConfigurationModifyParams,
)
from stripe.params.billing_portal._configuration_retrieve_params import (
    ConfigurationRetrieveParams as ConfigurationRetrieveParams,
)
from stripe.params.billing_portal._configuration_update_params import (
    ConfigurationUpdateParams as ConfigurationUpdateParams,
)
from stripe.params.billing_portal._session_create_params import (
    SessionCreateParams as SessionCreateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.tax._calculation_create_params import (
    CalculationCreateParams as CalculationCreateParams,
)
from stripe.params.tax._calculation_line_item_list_params import (
    CalculationLineItemListParams as CalculationLineItemListParams,
)
from stripe.params.tax._calculation_list_line_items_params import (
    CalculationListLineItemsParams as CalculationListLineItemsParams,
)
from stripe.params.tax._calculation_retrieve_params import (
    CalculationRetrieveParams as CalculationRetrieveParams,
)
from stripe.params.tax._registration_create_params import (
    RegistrationCreateParams as RegistrationCreateParams,
)
from stripe.params.tax._registration_list_params import (
    RegistrationListParams as RegistrationListParams,
)
from stripe.params.tax._registration_modify_params import (
    RegistrationModifyParams as RegistrationModifyParams,
)
from stripe.params.tax._registration_retrieve_params import (
    RegistrationRetrieveParams as RegistrationRetrieveParams,
)
from stripe.params.tax._registration_update_params import (
    RegistrationUpdateParams as RegistrationUpdateParams,
)
from stripe.params.tax._settings_modify_params import (
    SettingsModifyParams as SettingsModifyParams,
)
from stripe.params.tax._settings_retrieve_params import (
    SettingsRetrieveParams as SettingsRetrieveParams,
)
from stripe.params.tax._settings_update_params import (
    SettingsUpdateParams as SettingsUpdateParams,
)
from stripe.params.tax._transaction_create_from_calculation_params import (
    TransactionCreateFromCalculationParams as TransactionCreateFromCalculationParams,
)
from stripe.params.tax._transaction_create_reversal_params import (
    TransactionCreateReversalParams as TransactionCreateReversalParams,
)
from stripe.params.tax._transaction_line_item_list_params import (
    TransactionLineItemListParams as TransactionLineItemListParams,
)
from stripe.params.tax._transaction_list_line_items_params import (
    TransactionListLineItemsParams as TransactionListLineItemsParams,
)
from stripe.params.tax._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._application_fee import ApplicationFee
from stripe._application_fee_refund_service import ApplicationFeeRefundService
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params._application_fee_list_params import (
        ApplicationFeeListParams,
    )
    from stripe.params._application_fee_retrieve_params import (
        ApplicationFeeRetrieveParams,
    )


class ApplicationFeeService(StripeService):
    def __init__(self, requestor):
        super().__init__(requestor)
        self.refunds = ApplicationFeeRefundService(self._requestor)

    def list(
        self,
        params: Optional["ApplicationFeeListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[ApplicationFee]:
        """
        Returns a list of application fees you've previously collected. The application fees are returned in sorted order, with the most recent fees appearing first.
        """
        return cast(
            ListObject[ApplicationFee],
            self._request(
                "get",
                "/v1/application_fees",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["ApplicationFeeListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[ApplicationFee]:
        """
        Returns a list of application fees you've previously collected. The application fees are returned in sorted order, with the most recent fees appearing first.
        """
        return cast(
            ListObject[ApplicationFee],
            await self._request_async(
                "get",
                "/v1/application_fees",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["ApplicationFeeRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ApplicationFee:
        """
        Retrieves the details of an application fee that your account has collected. The same information is returned when refunding the application fee.
        """
        return cast(
            ApplicationFee,
            self._request(
                "get",
                "/v1/application_fees/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["ApplicationFeeRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ApplicationFee:
        """
        Retrieves the details of an application fee that your account has collected. The same information is returned when refunding the application fee.
        """
        return cast(
            ApplicationFee,
            await self._request_async(
                "get",
                "/v1/application_fees/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import Dict, List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class ConfigurationCreateParams(RequestOptions):
    business_profile: NotRequired["ConfigurationCreateParamsBusinessProfile"]
    """
    The business information shown to customers in the portal.
    """
    default_return_url: NotRequired["Literal['']|str"]
    """
    The default URL to redirect customers to when they click on the portal's link to return to your website. This can be [overriden](https://stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    features: "ConfigurationCreateParamsFeatures"
    """
    Information about the features available in the portal.
    """
    login_page: NotRequired["ConfigurationCreateParamsLoginPage"]
    """
    The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](https://stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).
    """
    metadata: NotRequired[Dict[str, str]]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    name: NotRequired["Literal['']|str"]
    """
    The name of the configuration.
    """


class ConfigurationCreateParamsBusinessProfile(TypedDict):
    headline: NotRequired["Literal['']|str"]
    """
    The messaging shown to customers in the portal.
    """
    privacy_policy_url: NotRequired[str]
    """
    A link to the business's publicly available privacy policy.
    """
    terms_of_service_url: NotRequired[str]
    """
    A link to the business's publicly available terms of service.
    """


class ConfigurationCreateParamsFeatures(TypedDict):
    customer_update: NotRequired[
        "ConfigurationCreateParamsFeaturesCustomerUpdate"
    ]
    """
    Information about updating the customer details in the portal.
    """
    invoice_history: NotRequired[
        "ConfigurationCreateParamsFeaturesInvoiceHistory"
    ]
    """
    Information about showing the billing history in the portal.
    """
    payment_method_update: NotRequired[
        "ConfigurationCreateParamsFeaturesPaymentMethodUpdate"
    ]
    """
    Information about updating payment methods in the portal.
    """
    subscription_cancel: NotRequired[
        "ConfigurationCreateParamsFeaturesSubscriptionCancel"
    ]
    """
    Information about canceling subscriptions in the portal.
    """
    subscription_update: NotRequired[
        "ConfigurationCreateParamsFeaturesSubscriptionUpdate"
    ]
    """
    Information about updating subscriptions in the portal.
    """


class ConfigurationCreateParamsFeaturesCustomerUpdate(TypedDict):
    allowed_updates: NotRequired[
        "Literal['']|List[Literal['address', 'email', 'name', 'phone', 'shipping', 'tax_id']]"
    ]
    """
    The types of customer updates that are supported. When empty, customers are not updateable.
    """
    enabled: bool
    """
    Whether the feature is enabled.
    """


class ConfigurationCreateParamsFeaturesInvoiceHistory(TypedDict):
    enabled: bool
    """
    Whether the feature is enabled.
    """


class ConfigurationCreateParamsFeaturesPaymentMethodUpdate(TypedDict):
    enabled: bool
    """
    Whether the feature is enabled.
    """


class ConfigurationCreateParamsFeaturesSubscriptionCancel(TypedDict):
    cancellation_reason: NotRequired[
        "ConfigurationCreateParamsFeaturesSubscriptionCancelCancellationReason"
    ]
    """
    Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer
    """
    enabled: bool
    """
    Whether the feature is enabled.
    """
    mode: NotRequired[Literal["at_period_end", "immediately"]]
    """
    Whether to cancel subscriptions immediately or at the end of the billing period.
    """
    proration_behavior: NotRequired[
        Literal["always_invoice", "create_prorations", "none"]
    ]
    """
    Whether to create prorations when canceling subscriptions. Possible values are `none` and `create_prorations`, which is only compatible with `mode=immediately`. Passing `always_invoice` will result in an error. No prorations are generated when canceling a subscription at the end of its natural billing period.
    """


class ConfigurationCreateParamsFeaturesSubscriptionCancelCancellationReason(
    TypedDict,
):
    enabled: bool
    """
    Whether the feature is enabled.
    """
    options: Union[
        Literal[""],
        List[
            Literal[
                "customer_service",
                "low_quality",
                "missing_features",
                "other",
                "switched_service",
                "too_complex",
                "too_expensive",
                "unused",
            ]
        ],
    ]
    """
    Which cancellation reasons will be given as options to the customer.
    """


class ConfigurationCreateParamsFeaturesSubscriptionUpdate(TypedDict):
    default_allowed_updates: NotRequired[
        "Literal['']|List[Literal['price', 'promotion_code', 'quantity']]"
    ]
    """
    The types of subscription updates that are supported. When empty, subscriptions are not updateable.
    """
    enabled: bool
    """
    Whether the feature is enabled.
    """
    products: NotRequired[
        "Literal['']|List[ConfigurationCreateParamsFeaturesSubscriptionUpdateProduct]"
    ]
    """
    The list of up to 10 products that support subscription updates.
    """
    proration_behavior: NotRequired[
        Literal["always_invoice", "create_prorations", "none"]
    ]
    """
    Determines how to handle prorations resulting from subscription updates. Valid values are `none`, `create_prorations`, and `always_invoice`.
    """
    schedule_at_period_end: NotRequired[
        "ConfigurationCreateParamsFeaturesSubscriptionUpdateScheduleAtPeriodEnd"
    ]
    """
    Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
    """
    trial_update_behavior: NotRequired[Literal["continue_trial", "end_trial"]]
    """
    The behavior when updating a subscription that is trialing.
    """


class ConfigurationCreateParamsFeaturesSubscriptionUpdateProduct(TypedDict):
    adjustable_quantity: NotRequired[
        "ConfigurationCreateParamsFeaturesSubscriptionUpdateProductAdjustableQuantity"
    ]
    """
    Control whether the quantity of the product can be adjusted.
    """
    prices: List[str]
    """
    The list of price IDs for the product that a subscription can be updated to.
    """
    product: str
    """
    The product id.
    """


class ConfigurationCreateParamsFeaturesSubscriptionUpdateProductAdjustableQuantity(
    TypedDict,
):
    enabled: bool
    """
    Set to true if the quantity can be adjusted to any non-negative integer.
    """
    maximum: NotRequired[int]
    """
    The maximum quantity that can be set for the product.
    """
    minimum: NotRequired[int]
    """
    The minimum quantity that can be set for the product.
    """


class ConfigurationCreateParamsFeaturesSubscriptionUpdateScheduleAtPeriodEnd(
    TypedDict,
):
    conditions: NotRequired[
        List[
            "ConfigurationCreateParamsFeaturesSubscriptionUpdateScheduleAtPeriodEndCondition"
        ]
    ]
    """
    List of conditions. When any condition is true, the update will be scheduled at the end of the current period.
    """


class ConfigurationCreateParamsFeaturesSubscriptionUpdateScheduleAtPeriodEndCondition(
    TypedDict,
):
    type: Literal["decreasing_item_amount", "shortening_interval"]
    """
    The type of condition.
    """


class ConfigurationCreateParamsLoginPage(TypedDict):
    enabled: bool
    """
    Set to `true` to generate a shareable URL [`login_page.url`](https://stripe.com/docs/api/customer_portal/configuration#portal_configuration_object-login_page-url) that will take your customers to a hosted login page for the customer portal.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.treasury._credit_reversal_create_params import (
    CreditReversalCreateParams as CreditReversalCreateParams,
)
from stripe.params.treasury._credit_reversal_list_params import (
    CreditReversalListParams as CreditReversalListParams,
)
from stripe.params.treasury._credit_reversal_retrieve_params import (
    CreditReversalRetrieveParams as CreditReversalRetrieveParams,
)
from stripe.params.treasury._debit_reversal_create_params import (
    DebitReversalCreateParams as DebitReversalCreateParams,
)
from stripe.params.treasury._debit_reversal_list_params import (
    DebitReversalListParams as DebitReversalListParams,
)
from stripe.params.treasury._debit_reversal_retrieve_params import (
    DebitReversalRetrieveParams as DebitReversalRetrieveParams,
)
from stripe.params.treasury._financial_account_close_params import (
    FinancialAccountCloseParams as FinancialAccountCloseParams,
)
from stripe.params.treasury._financial_account_create_params import (
    FinancialAccountCreateParams as FinancialAccountCreateParams,
)
from stripe.params.treasury._financial_account_features_retrieve_params import (
    FinancialAccountFeaturesRetrieveParams as FinancialAccountFeaturesRetrieveParams,
)
from stripe.params.treasury._financial_account_features_update_params import (
    FinancialAccountFeaturesUpdateParams as FinancialAccountFeaturesUpdateParams,
)
from stripe.params.treasury._financial_account_list_params import (
    FinancialAccountListParams as FinancialAccountListParams,
)
from stripe.params.treasury._financial_account_modify_params import (
    FinancialAccountModifyParams as FinancialAccountModifyParams,
)
from stripe.params.treasury._financial_account_retrieve_features_params import (
    FinancialAccountRetrieveFeaturesParams as FinancialAccountRetrieveFeaturesParams,
)
from stripe.params.treasury._financial_account_retrieve_params import (
    FinancialAccountRetrieveParams as FinancialAccountRetrieveParams,
)
from stripe.params.treasury._financial_account_update_features_params import (
    FinancialAccountUpdateFeaturesParams as FinancialAccountUpdateFeaturesParams,
)
from stripe.params.treasury._financial_account_update_params import (
    FinancialAccountUpdateParams as FinancialAccountUpdateParams,
)
from stripe.params.treasury._inbound_transfer_cancel_params import (
    InboundTransferCancelParams as InboundTransferCancelParams,
)
from stripe.params.treasury._inbound_transfer_create_params import (
    InboundTransferCreateParams as InboundTransferCreateParams,
)
from stripe.params.treasury._inbound_transfer_fail_params import (
    InboundTransferFailParams as InboundTransferFailParams,
)
from stripe.params.treasury._inbound_transfer_list_params import (
    InboundTransferListParams as InboundTransferListParams,
)
from stripe.params.treasury._inbound_transfer_retrieve_params import (
    InboundTransferRetrieveParams as InboundTransferRetrieveParams,
)
from stripe.params.treasury._inbound_transfer_return_inbound_transfer_params import (
    InboundTransferReturnInboundTransferParams as InboundTransferReturnInboundTransferParams,
)
from stripe.params.treasury._inbound_transfer_succeed_params import (
    InboundTransferSucceedParams as InboundTransferSucceedParams,
)
from stripe.params.treasury._outbound_payment_cancel_params import (
    OutboundPaymentCancelParams as OutboundPaymentCancelParams,
)
from stripe.params.treasury._outbound_payment_create_params import (
    OutboundPaymentCreateParams as OutboundPaymentCreateParams,
)
from stripe.params.treasury._outbound_payment_fail_params import (
    OutboundPaymentFailParams as OutboundPaymentFailParams,
)
from stripe.params.treasury._outbound_payment_list_params import (
    OutboundPaymentListParams as OutboundPaymentListParams,
)
from stripe.params.treasury._outbound_payment_post_params import (
    OutboundPaymentPostParams as OutboundPaymentPostParams,
)
from stripe.params.treasury._outbound_payment_retrieve_params import (
    OutboundPaymentRetrieveParams as OutboundPaymentRetrieveParams,
)
from stripe.params.treasury._outbound_payment_return_outbound_payment_params import (
    OutboundPaymentReturnOutboundPaymentParams as OutboundPaymentReturnOutboundPaymentParams,
)
from stripe.params.treasury._outbound_payment_update_params import (
    OutboundPaymentUpdateParams as OutboundPaymentUpdateParams,
)
from stripe.params.treasury._outbound_transfer_cancel_params import (
    OutboundTransferCancelParams as OutboundTransferCancelParams,
)
from stripe.params.treasury._outbound_transfer_create_params import (
    OutboundTransferCreateParams as OutboundTransferCreateParams,
)
from stripe.params.treasury._outbound_transfer_fail_params import (
    OutboundTransferFailParams as OutboundTransferFailParams,
)
from stripe.params.treasury._outbound_transfer_list_params import (
    OutboundTransferListParams as OutboundTransferListParams,
)
from stripe.params.treasury._outbound_transfer_post_params import (
    OutboundTransferPostParams as OutboundTransferPostParams,
)
from stripe.params.treasury._outbound_transfer_retrieve_params import (
    OutboundTransferRetrieveParams as OutboundTransferRetrieveParams,
)
from stripe.params.treasury._outbound_transfer_return_outbound_transfer_params import (
    OutboundTransferReturnOutboundTransferParams as OutboundTransferReturnOutboundTransferParams,
)
from stripe.params.treasury._outbound_transfer_update_params import (
    OutboundTransferUpdateParams as OutboundTransferUpdateParams,
)
from stripe.params.treasury._received_credit_create_params import (
    ReceivedCreditCreateParams as ReceivedCreditCreateParams,
)
from stripe.params.treasury._received_credit_list_params import (
    ReceivedCreditListParams as ReceivedCreditListParams,
)
from stripe.params.treasury._received_credit_retrieve_params import (
    ReceivedCreditRetrieveParams as ReceivedCreditRetrieveParams,
)
from stripe.params.treasury._received_debit_create_params import (
    ReceivedDebitCreateParams as ReceivedDebitCreateParams,
)
from stripe.params.treasury._received_debit_list_params import (
    ReceivedDebitListParams as ReceivedDebitListParams,
)
from stripe.params.treasury._received_debit_retrieve_params import (
    ReceivedDebitRetrieveParams as ReceivedDebitRetrieveParams,
)
from stripe.params.treasury._transaction_entry_list_params import (
    TransactionEntryListParams as TransactionEntryListParams,
)
from stripe.params.treasury._transaction_entry_retrieve_params import (
    TransactionEntryRetrieveParams as TransactionEntryRetrieveParams,
)
from stripe.params.treasury._transaction_list_params import (
    TransactionListParams as TransactionListParams,
)
from stripe.params.treasury._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.tax._transaction_line_item import TransactionLineItem
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.tax._transaction_line_item_list_params import (
        TransactionLineItemListParams,
    )


class TransactionLineItemService(StripeService):
    def list(
        self,
        transaction: str,
        params: Optional["TransactionLineItemListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[TransactionLineItem]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject[TransactionLineItem],
            self._request(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        transaction: str,
        params: Optional["TransactionLineItemListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[TransactionLineItem]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject[TransactionLineItem],
            await self._request_async(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(transaction),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._list_object import ListObject
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.checkout._session import Session
from stripe.checkout._session_line_item_service import SessionLineItemService
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.checkout._session_create_params import (
        SessionCreateParams,
    )
    from stripe.params.checkout._session_expire_params import (
        SessionExpireParams,
    )
    from stripe.params.checkout._session_list_params import SessionListParams
    from stripe.params.checkout._session_retrieve_params import (
        SessionRetrieveParams,
    )
    from stripe.params.checkout._session_update_params import (
        SessionUpdateParams,
    )


class SessionService(StripeService):
    def __init__(self, requestor):
        super().__init__(requestor)
        self.line_items = SessionLineItemService(self._requestor)

    def list(
        self,
        params: Optional["SessionListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Session]:
        """
        Returns a list of Checkout Sessions.
        """
        return cast(
            ListObject[Session],
            self._request(
                "get",
                "/v1/checkout/sessions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["SessionListParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> ListObject[Session]:
        """
        Returns a list of Checkout Sessions.
        """
        return cast(
            ListObject[Session],
            await self._request_async(
                "get",
                "/v1/checkout/sessions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: Optional["SessionCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Creates a Checkout Session object.
        """
        return cast(
            Session,
            self._request(
                "post",
                "/v1/checkout/sessions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: Optional["SessionCreateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Creates a Checkout Session object.
        """
        return cast(
            Session,
            await self._request_async(
                "post",
                "/v1/checkout/sessions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        session: str,
        params: Optional["SessionRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Retrieves a Checkout Session object.
        """
        return cast(
            Session,
            self._request(
                "get",
                "/v1/checkout/sessions/{session}".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        session: str,
        params: Optional["SessionRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Retrieves a Checkout Session object.
        """
        return cast(
            Session,
            await self._request_async(
                "get",
                "/v1/checkout/sessions/{session}".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        session: str,
        params: Optional["SessionUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Updates a Checkout Session object.

        Related guide: [Dynamically update Checkout](https://docs.stripe.com/payments/checkout/dynamic-updates)
        """
        return cast(
            Session,
            self._request(
                "post",
                "/v1/checkout/sessions/{session}".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        session: str,
        params: Optional["SessionUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        Updates a Checkout Session object.

        Related guide: [Dynamically update Checkout](https://docs.stripe.com/payments/checkout/dynamic-updates)
        """
        return cast(
            Session,
            await self._request_async(
                "post",
                "/v1/checkout/sessions/{session}".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def expire(
        self,
        session: str,
        params: Optional["SessionExpireParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        A Checkout Session can be expired when it is in one of these statuses: open

        After it expires, a customer can't complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.
        """
        return cast(
            Session,
            self._request(
                "post",
                "/v1/checkout/sessions/{session}/expire".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def expire_async(
        self,
        session: str,
        params: Optional["SessionExpireParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> Session:
        """
        A Checkout Session can be expired when it is in one of these statuses: open

        After it expires, a customer can't complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.
        """
        return cast(
            Session,
            await self._request_async(
                "post",
                "/v1/checkout/sessions/{session}/expire".format(
                    session=sanitize_id(session),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-

from stripe.v2.core._event import (
    EventNotification as EventNotification,
    RelatedObject as RelatedObject,
    Reason as Reason,
    ReasonRequest as ReasonRequest,
)

# The beginning of the section generated from our OpenAPI spec
from stripe.v2.core._event import Event as Event
from stripe.v2.core._event_destination import (
    EventDestination as EventDestination,
)
from stripe.v2.core._event_destination_service import (
    EventDestinationService as EventDestinationService,
)
from stripe.v2.core._event_service import EventService as EventService
# The end of the section generated from our OpenAPI spec



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.test_helpers.treasury._inbound_transfer_fail_params import (
    InboundTransferFailParams as InboundTransferFailParams,
)
from stripe.params.test_helpers.treasury._inbound_transfer_return_inbound_transfer_params import (
    InboundTransferReturnInboundTransferParams as InboundTransferReturnInboundTransferParams,
)
from stripe.params.test_helpers.treasury._inbound_transfer_succeed_params import (
    InboundTransferSucceedParams as InboundTransferSucceedParams,
)
from stripe.params.test_helpers.treasury._outbound_payment_fail_params import (
    OutboundPaymentFailParams as OutboundPaymentFailParams,
)
from stripe.params.test_helpers.treasury._outbound_payment_post_params import (
    OutboundPaymentPostParams as OutboundPaymentPostParams,
)
from stripe.params.test_helpers.treasury._outbound_payment_return_outbound_payment_params import (
    OutboundPaymentReturnOutboundPaymentParams as OutboundPaymentReturnOutboundPaymentParams,
)
from stripe.params.test_helpers.treasury._outbound_payment_update_params import (
    OutboundPaymentUpdateParams as OutboundPaymentUpdateParams,
)
from stripe.params.test_helpers.treasury._outbound_transfer_fail_params import (
    OutboundTransferFailParams as OutboundTransferFailParams,
)
from stripe.params.test_helpers.treasury._outbound_transfer_post_params import (
    OutboundTransferPostParams as OutboundTransferPostParams,
)
from stripe.params.test_helpers.treasury._outbound_transfer_return_outbound_transfer_params import (
    OutboundTransferReturnOutboundTransferParams as OutboundTransferReturnOutboundTransferParams,
)
from stripe.params.test_helpers.treasury._outbound_transfer_update_params import (
    OutboundTransferUpdateParams as OutboundTransferUpdateParams,
)
from stripe.params.test_helpers.treasury._received_credit_create_params import (
    ReceivedCreditCreateParams as ReceivedCreditCreateParams,
)
from stripe.params.test_helpers.treasury._received_debit_create_params import (
    ReceivedDebitCreateParams as ReceivedDebitCreateParams,
)
